@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -404,7 +409,8 @@ Constraint::readOtherXML (XMLInputStream& stream)
       }
       else
       {
-        logError(OneMathElementPerConstraint, getLevel(), getVersion());
+        logError(OneMathElementPerConstraint, getLevel(), getVersion(),
+          "The <constraint> contains more than one <math> element.");
       }
     }
     // If there's a <message>, it's supposed to show up first
@@ -752,29 +758,9 @@ ListOfConstraints::createObject (XMLInputStream& stream)
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 
-/**
- * Creates a new Constraint_t structure using the given SBML @p level
- * and @p version values.
- *
- * @param level an unsigned int, the SBML Level to assign to this
- * Constraint
- *
- * @param version an unsigned int, the SBML Version to assign to this
- * Constraint
- *
- * @return a pointer to the newly created Constraint_t structure.
- *
- * @note Once a Constraint has been added to an SBMLDocument, the @p
- * level and @p version for the document @em override those used to create
- * the Constraint.  Despite this, the ability to supply the values at
- * creation time is an important aid to creating valid SBML.  Knowledge of
- * the intended SBML Level and Version  determine whether it is valid to
- * assign a particular value to an attribute, or whether it is valid to add
- * an object to an existing SBMLDocument.
- */
 LIBSBML_EXTERN
 Constraint_t *
 Constraint_create (unsigned int level, unsigned int version)
@@ -791,23 +777,6 @@ Constraint_create (unsigned int level, unsigned int version)
 }
 
 
-/**
- * Creates a new Constraint_t structure using the given
- * SBMLNamespaces_t structure.
- *
- * @param sbmlns SBMLNamespaces, a pointer to an SBMLNamespaces structure
- * to assign to this Constraint
- *
- * @return a pointer to the newly created Constraint_t structure.
- *
- * @note Once a Constraint has been added to an SBMLDocument, the
- * @p sbmlns namespaces for the document @em override those used to create
- * the Constraint.  Despite this, the ability to supply the values at creation 
- * time is an important aid to creating valid SBML.  Knowledge of the intended 
- * SBML Level and Version determine whether it is valid to assign a particular 
- * value to an attribute, or whether it is valid to add an object to an existing
- * SBMLDocument.
- */
 LIBSBML_EXTERN
 Constraint_t *
 Constraint_createWithNS (SBMLNamespaces_t* sbmlns)
@@ -824,9 +793,6 @@ Constraint_createWithNS (SBMLNamespaces_t* sbmlns)
 }
 
 
-/**
- * Frees the given Constraint_t structure.
- */
 LIBSBML_EXTERN
 void
 Constraint_free (Constraint_t *c)
@@ -836,13 +802,6 @@ Constraint_free (Constraint_t *c)
 }
 
 
-/**
- * Creates and returns a deep copy of the given Constraint_t structure.
- *
- * @param c the Constraint_t structure to copy
- * 
- * @return a (deep) copy of Constraint_t.
- */
 LIBSBML_EXTERN
 Constraint_t *
 Constraint_clone (const Constraint_t *c)
@@ -858,15 +817,6 @@ Constraint_clone (const Constraint_t *c)
 }
 
 
-/**
- * Returns a list of XMLNamespaces_t associated with this Constraint_t
- * structure.
- *
- * @param c the Constraint_t structure
- * 
- * @return pointer to the XMLNamespaces_t structure associated with 
- * this SBML object
- */
 LIBSBML_EXTERN
 const XMLNamespaces_t *
 Constraint_getNamespaces(Constraint_t *c)
@@ -881,13 +831,6 @@ Constraint_getNamespaces(Constraint_t *c)
   }
 }
 
-/**
- * Get the message, if any, associated with this Constraint
- *
- * @param c the Constraint_t structure 
- * 
- * @return the message for this Constraint, as an XMLNode.
- */
 LIBSBML_EXTERN
 const XMLNode_t *
 Constraint_getMessage (const Constraint_t *c)
@@ -896,16 +839,6 @@ Constraint_getMessage (const Constraint_t *c)
 }
 
 
-/**
- * Get the message string, if any, associated with this Constraint
- *
- * @param c the Constraint_t structure 
- * 
- * @return the message for this Constraint, as a string (char*).
- * @c NULL is returned if the message is not set.
- *
- * @note returned char* should be freed with safe_free() by the caller.
- */
 LIBSBML_EXTERN
 char*
 Constraint_getMessageString (const Constraint_t *c)
@@ -915,13 +848,6 @@ Constraint_getMessageString (const Constraint_t *c)
 }
 
 
-/**
- * Get the mathematical expression of this Constraint
- *
- * @param c the Constraint_t structure 
- * 
- * @return the math for this Constraint, as an ASTNode.
- */
 LIBSBML_EXTERN
 const ASTNode_t *
 Constraint_getMath (const Constraint_t *c)
@@ -930,15 +856,6 @@ Constraint_getMath (const Constraint_t *c)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether a
- * message is defined for this Constraint.
- *
- * @param c the Constraint_t structure 
- * 
- * @return a nonzero integer if the "message" subelement for this
- * Constraint is set, zero (0) otherwise.
- */
 LIBSBML_EXTERN
 int
 Constraint_isSetMessage (const Constraint_t *c)
@@ -947,15 +864,6 @@ Constraint_isSetMessage (const Constraint_t *c)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether a
- * mathematical formula is defined for this Constraint.
- *
- * @param c the Constraint_t structure 
- * 
- * @return a nonzero integer if the "math" subelement for this Constraint
- * is set, zero (0) otherwise.
- */
 LIBSBML_EXTERN
 int
 Constraint_isSetMath (const Constraint_t *c)
@@ -964,20 +872,6 @@ Constraint_isSetMath (const Constraint_t *c)
 }
 
 
-/**
- * Sets the message of this Constraint.
- *
- * @param c the Constraint_t structure
- *
- * @param xhtml an XML tree containing XHTML content.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_OBJECT
- */
 LIBSBML_EXTERN
 int
 Constraint_setMessage (Constraint_t *c, const XMLNode_t *xhtml)
@@ -993,21 +887,6 @@ Constraint_setMessage (Constraint_t *c, const XMLNode_t *xhtml)
 }
 
 
-/**
- * Sets the mathematical expression of this Constraint.
- *
- * @param c the Constraint_t structure
- *
- * @param math an ASTNode expression to be assigned as the "math"
- * subelement of this Constraint
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_OBJECT
- */
 LIBSBML_EXTERN
 int
 Constraint_setMath (Constraint_t *c, const ASTNode_t *math)
@@ -1023,18 +902,6 @@ Constraint_setMath (Constraint_t *c, const ASTNode_t *math)
 }
 
 
-/**
- * Unsets the "message" subelement of this Constraint.
- *
- * @param c the Constraint_t structure
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_OPERATION_FAILED
- */
 LIBSBML_EXTERN
 int 
 Constraint_unsetMessage (Constraint_t *c)
