@@ -558,9 +558,12 @@ SBMLDocument::updateSBMLNamespace(const std::string& package, unsigned int level
         uri = SBML_XMLNS_L2V3;
         break;
       case 4:
-      default:
         uri = SBML_XMLNS_L2V4;
         break;
+      case 5:
+      default:
+        uri = SBML_XMLNS_L2V5;
+        break;
       }
       break;
     case 3:
@@ -940,7 +943,8 @@ SBMLDocument::getNumErrors () const
 unsigned int 
 SBMLDocument::getNumErrors (unsigned int severity) const
 {
-  return getErrorLog()->getNumFailsWithSeverity(severity);
+  return ((getErrorLog() != NULL) ? 
+      getErrorLog()->getNumFailsWithSeverity(severity) : 0);
 }
 
 
@@ -1060,13 +1064,19 @@ SBMLDocument::createObject (XMLInputStream& stream)
 
   if (name == "model")
   {
-    // check that we do not already have a model
-    if (isSetModel() == true)
+    if (mModel != NULL)
     {
-      logError(NotSchemaConformant, getLevel(), getVersion(), 
-        "Only one <model> element is allowed within an SBMLDocument.");
+      if (getLevel() < 3 || (getLevel() == 3 && getVersion() < 2)) 
+      {
+        logError(NotSchemaConformant, getLevel(), getVersion(),
+	        "Only one <model> element is permitted inside a "
+	        "document.");
+      }
+      else
+      {
+        logError(MissingModel, getLevel(), getVersion());
+      }
     }
-
     delete mModel;
 
     try
@@ -1351,6 +1361,52 @@ SBMLDocument::hasUnknownPackage(const std::string& pkgURI)
 
   return false;
 }
+
+
+int 
+SBMLDocument::getNumUnknownPackages() const
+{
+  int count = 0;
+  for (int i = 0; i < mRequiredAttrOfUnknownPkg.getLength(); ++i)
+  {
+    if (mRequiredAttrOfUnknownPkg.getName(i) == "required")
+      ++count;
+  }
+  return count;
+}
+
+std::string 
+SBMLDocument::getUnknownPackageURI(int index) const
+{
+  std::string result;
+  int count = 0;
+  for (int i = 0; i < mRequiredAttrOfUnknownPkg.getLength(); ++i)
+  {
+    if (mRequiredAttrOfUnknownPkg.getName(i) != "required")
+      continue;
+    if (i == count)
+      return mRequiredAttrOfUnknownPkg.getURI(i);
+    ++count;
+  }
+  return result;
+}
+
+std::string
+SBMLDocument::getUnknownPackagePrefix(int index) const
+{
+  std::string result;
+  int count = 0;
+  for (int i = 0; i < mRequiredAttrOfUnknownPkg.getLength(); ++i)
+  {
+    if (mRequiredAttrOfUnknownPkg.getName(i) != "required")
+      continue;
+    if (i == count)
+      return mRequiredAttrOfUnknownPkg.getPrefix(i);
+    ++count;
+  }
+  return result;
+}
+
 /** @endcond */
 
 
@@ -1520,7 +1576,7 @@ SBMLDocument::readAttributes (const XMLAttributes& attributes,
   }
   else if (mLevel == 2)
   {
-    if (mVersion > 4)
+    if (mVersion > 5)
     {
       logError(InvalidSBMLLevelVersion);
     }
@@ -1619,6 +1675,20 @@ SBMLDocument::readAttributes (const XMLAttributes& attributes,
         }
         break;
       }
+      else if (!strcmp(ns->getURI(n).c_str(), 
+                "http://www.sbml.org/sbml/level2/version5"))
+      {
+        match = 1;
+        if (mLevel != 2 || !levelRead)
+        {
+          logError(MissingOrInconsistentLevel);
+        }
+        if (mVersion != 5 || !versionRead)
+        {
+          logError(MissingOrInconsistentVersion);
+        }
+        break;
+      }
       else if (!strcmp(ns->getURI(n).c_str(), 
                 "http://www.sbml.org/sbml/level3/version1/core"))
       {
