@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -640,6 +645,17 @@ SBO::isSystemsDescriptionParameter  (unsigned int sboTerm)
 }
 
 
+/**
+  * functions for checking the SBO term is from correct part of SBO
+  * returns true if the term is-a QuantitativeSystemsDescriptionParameter, false otherwise
+  */
+bool
+SBO::isQuantitativeSystemsDescriptionParameter  (unsigned int sboTerm)
+{
+  return SBO::isQuantitativeParameter(sboTerm);
+}
+
+
 /*
  * Function for checking the SBO term is Obselete
  *
@@ -665,7 +681,7 @@ SBO::isObselete  (unsigned int sboTerm)
 void
 SBO::populateSBOTree()
 {
-  // generated from SBO on October 25th 2013
+  // generated from SBO on October 31st 2014
   mParent.insert( pair<const int, int>(  1,  64) );
   mParent.insert( pair<const int, int>(  2, 545) );
   mParent.insert( pair<const int, int>(  3,   0) );
@@ -1320,6 +1336,13 @@ SBO::populateSBOTree()
   mParent.insert( pair<const int, int>(602, 546) );
   mParent.insert( pair<const int, int>(603,  11) );
   mParent.insert( pair<const int, int>(604,  15) );
+  mParent.insert( pair<const int, int>(605, 244) );
+  mParent.insert( pair<const int, int>(606, 244) );
+  mParent.insert( pair<const int, int>(607, 296) );
+  mParent.insert( pair<const int, int>(608, 607) );
+  mParent.insert( pair<const int, int>(609, 607) );
+  mParent.insert( pair<const int, int>(610,   2) );
+  mParent.insert( pair<const int, int>(611,   9) );
 
 
 
@@ -1327,7 +1350,7 @@ SBO::populateSBOTree()
 /** @endcond */
 
 #endif /* __cplusplus */  
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 /** @endcond */
 
