@@ -31,8 +31,7 @@
  * ---------------------------------------------------------------------- -->
  *
  * @class SBO
- * @sbmlbrief{core} Methods for interacting with Systems Biology Ontology
- * terms.
+ * @sbmlbrief{core} Facilities for using the Systems Biology Ontology.
  *
  * @htmlinclude not-sbml-warning.html
  *
@@ -84,7 +83,7 @@
  * this is simply impossible to do: not only do humans often disagree on
  * the names themselves, but it would not allow for correction of errors or
  * updates to the list of predefined names except by issuing new releases
- * of the SBML specification&mdash;to say nothing of many other limitations
+ * of the SBML specification---to say nothing of many other limitations
  * with this approach.  Moreover, the parameters and variables that appear
  * in rate expressions also need to be identified in a way that software
  * tools can interpret mechanically, implying that the names of these
@@ -508,6 +507,17 @@ public:
   static bool isSystemsDescriptionParameter  (unsigned int term);
 
 
+  /**
+   * Returns @c true if the given term identifier comes from the stated branch of %SBO.
+   *
+   * @return @c true if @p term is-a %SBO <em>"quantiative systems description parameter"</em>, @c false
+   * otherwise.
+   *
+   * @copydetails doc_note_static_methods
+   */
+  static bool isQuantitativeSystemsDescriptionParameter  (unsigned int term);
+
+
   /**
    * Predicate for checking whether the given term is obsolete.
    *
