@@ -5,7 +5,7 @@
  * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -58,6 +58,7 @@ LIBSBML_CPP_NAMESPACE_BEGIN
  */
 CVTerm::CVTerm(QualifierType_t type) :
     mHasBeenModified (false)
+  , mNestedCVTerms (NULL)
 
 {
   mResources = new XMLAttributes();
@@ -78,6 +79,7 @@ CVTerm::CVTerm(QualifierType_t type) :
  */
 CVTerm::CVTerm(const XMLNode node) :
     mHasBeenModified (false)
+  , mNestedCVTerms(NULL)
 {
   const string& name = node.getName();
   const string& prefix = node.getPrefix();
@@ -103,9 +105,25 @@ CVTerm::CVTerm(const XMLNode node) :
 
   for (unsigned int n = 0; n < Bag.getNumChildren(); n++)
   {
-    for (int b = 0; b < Bag.getChild(n).getAttributes().getLength(); b++)
+    // need to look to see if we have a nested annotation
+    XMLNode child = Bag.getChild(n);
+
+    if (child.getNumChildren() == 0)
     {
-      addResource(Bag.getChild(n).getAttributes().getValue(b));
+      for (int b = 0; b < child.getAttributes().getLength(); b++)
+      {
+        addResource(child.getAttributes().getValue(b));
+      }
+    }
+    else
+    {
+      // check we have a correct node
+      if (mNestedCVTerms == NULL)
+      {
+        mNestedCVTerms = new List();
+      }
+      CVTerm *term = new CVTerm(child);
+      mNestedCVTerms->add((void *)(term));
     }
   }
 
@@ -118,6 +136,18 @@ CVTerm::CVTerm(const XMLNode node) :
 CVTerm::~CVTerm()
 {
   delete mResources;
+  mResources = NULL;
+
+  if (mNestedCVTerms != NULL)
+  {
+    unsigned int size = mNestedCVTerms->getSize();
+    while (size > 0) 
+    {
+      delete static_cast<CVTerm*>( mNestedCVTerms->remove(0) );
+      size--;
+    }
+    delete mNestedCVTerms;
+  }
 }
 
 /*
@@ -138,6 +168,21 @@ CVTerm::CVTerm(const CVTerm& orig)
     mBiolQualifier  = orig.mBiolQualifier;
     mResources      = new XMLAttributes(*orig.mResources);
     mHasBeenModified = orig.mHasBeenModified;
+
+    if(orig.mNestedCVTerms != NULL)
+    {
+      this->mNestedCVTerms  = new List();
+      unsigned int i,iMax = orig.mNestedCVTerms->getSize();
+      for(i = 0; i < iMax; ++i)
+      {
+        this->mNestedCVTerms
+          ->add(static_cast<CVTerm*>(orig.mNestedCVTerms->get(i))->clone());
+      }
+    }
+    else
+    {
+      this->mNestedCVTerms = NULL;
+    }
   }
 }
 
@@ -161,6 +206,28 @@ CVTerm::operator=(const CVTerm& rhs)
     mResources=new XMLAttributes(*rhs.mResources);
 
     mHasBeenModified = rhs.mHasBeenModified;
+
+    if(this->mNestedCVTerms != NULL)
+    {
+      unsigned int size = this->mNestedCVTerms->getSize();
+      while (size--) delete static_cast<CVTerm*>( this->mNestedCVTerms->remove(0) );
+      delete this->mNestedCVTerms;
+    }
+
+    if(rhs.mNestedCVTerms != NULL)
+    {
+      this->mNestedCVTerms  = new List();
+      unsigned int i,iMax = rhs.mNestedCVTerms->getSize();
+      for(i = 0; i < iMax; ++i)
+      {
+        this->mNestedCVTerms
+          ->add(static_cast<CVTerm*>(rhs.mNestedCVTerms->get(i))->clone());
+      }
+    }
+    else
+    {
+      this->mNestedCVTerms = NULL;
+    }
   }
 
   return *this;
@@ -287,6 +354,13 @@ CVTerm::getQualifierType()
 }
 
 
+QualifierType_t 
+CVTerm::getQualifierType() const
+{
+  return mQualifier;
+}
+
+
 /*
  * gets the Model Qualifier type
  */
@@ -297,6 +371,13 @@ CVTerm::getModelQualifierType()
 }
 
 
+ModelQualifierType_t 
+CVTerm::getModelQualifierType() const
+{
+  return mModelQualifier;
+}
+
+
 /*
  * gets the biological Qualifier type
  */
@@ -307,6 +388,13 @@ CVTerm::getBiologicalQualifierType()
 }
 
 
+BiolQualifierType_t 
+CVTerm::getBiologicalQualifierType() const
+{
+  return mBiolQualifier;
+}
+
+
 /*
  * gets the resources
  */
@@ -336,6 +424,13 @@ CVTerm::getNumResources()
 }
 
   
+unsigned int 
+CVTerm::getNumResources() const
+{
+  return mResources->getLength();
+}
+
+  
 /*
  * Returns the value of the nth resource for this %CVTerm.
  */
@@ -346,6 +441,16 @@ CVTerm::getResourceURI(unsigned int n)
 }
 
   
+/*
+ * Returns the value of the nth resource for this %CVTerm.
+ */
+std::string
+CVTerm::getResourceURI(unsigned int n) const
+{
+  return mResources->getValue(n);
+}
+
+  
 /*
  * adds a resource to the term
  */
@@ -433,6 +538,41 @@ CVTerm::hasRequiredAttributes()
   return valid;
 }
 
+bool 
+CVTerm::hasRequiredAttributes() const
+{
+  bool valid = true;
+
+  if (getQualifierType() == UNKNOWN_QUALIFIER)
+  {
+    valid = false;
+  }
+  else if (getQualifierType() == MODEL_QUALIFIER)
+  {
+    if (getModelQualifierType() == BQM_UNKNOWN)
+    {
+      valid = false;
+    }
+  }
+  else
+  {
+    if (getBiologicalQualifierType() == BQB_UNKNOWN)
+    {
+      valid = false;
+    }
+  }
+
+  if (valid)
+  {
+    if (getResources()->isEmpty())
+    {
+      valid = false;
+    }
+  }
+
+  return valid;
+}
+
 bool
 CVTerm::hasBeenModified()
 {
@@ -445,23 +585,110 @@ CVTerm::resetModifiedFlags()
   mHasBeenModified = false;
 }
 
+void
+CVTerm::setHasBeenModifiedFlag()
+{
+  mHasBeenModified = true;
+}
+
+unsigned int
+CVTerm::getNumNestedCVTerms() const
+{
+  if (mNestedCVTerms != NULL)
+  {
+    return mNestedCVTerms->getSize();
+  }
+  else
+  {
+    return 0;
+  }
+}
+
+const CVTerm *
+CVTerm::getNestedCVTerm(unsigned int n) const
+{
+  return (mNestedCVTerms) ? static_cast <const CVTerm*> (mNestedCVTerms->get(n)) : NULL;
+}
+
+
+CVTerm *
+CVTerm::getNestedCVTerm(unsigned int n)
+{
+  return (mNestedCVTerms) ? static_cast <CVTerm*> (mNestedCVTerms->get(n)) : NULL;
+}
+
+
+List*
+CVTerm::getListNestedCVTerms()
+{
+  return mNestedCVTerms;
+}
+
+const List*
+CVTerm::getListNestedCVTerms() const
+{
+  return const_cast<const List*>(mNestedCVTerms);
+}
+
+
+int
+CVTerm::addNestedCVTerm(const CVTerm* term)
+{
+  if (term == NULL)
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }
+  else if (!term->hasRequiredAttributes())
+  {
+    return LIBSBML_INVALID_OBJECT;
+  }
+
+  if (mNestedCVTerms == NULL)
+  {
+    mNestedCVTerms = new List();
+  }
+
+  unsigned int num = mNestedCVTerms->getSize();
+  
+  mNestedCVTerms->add((void *) term->clone());
+  
+  if (mNestedCVTerms->getSize() == num+1)
+  {
+    mHasBeenModified = true;
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+  else
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }
+}
+
+
+CVTerm*
+CVTerm::removeNestedCVTerm(unsigned int n)
+{
+  CVTerm* removed = NULL;
+
+  unsigned int num = mNestedCVTerms->getSize();
+
+  if (n >= num)
+  {
+    return NULL;
+  }
+
+  removed = static_cast<CVTerm*>(mNestedCVTerms->remove(n));
+  mHasBeenModified = true;
+
+  return removed;
+}
+
 /** @endcond */
 #endif /* __cplusplus */
 
 
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 
-/**
- * Creates a new CVTerm_t with the given #QualifierType_t value @p type and
- * returns a pointer to it.
- *
- * The possible QualifierTypes are MODEL_QUALIFIER and BIOLOGICAL_QUALIFIER.  
- *
- * @param type a #QualifierType_t
- *
- * @return a pointer to the newly created CVTerm_t structure.
- */
 LIBSBML_EXTERN
 CVTerm_t*
 CVTerm_createWithQualifierType(QualifierType_t type)
@@ -469,22 +696,6 @@ CVTerm_createWithQualifierType(QualifierType_t type)
   return new(nothrow) CVTerm(type);
 }
 
-/**
- * Create a new CVTerm_t from the given XMLNode_t and returns a 
- * pointer to it.
- *
- * RDFAnnotations within a model are stored as a List of CVTerms.  This allows
- * the user to interact with the %CVTerms directly.  When LibSBML reads in a 
- * model containing RDFAnnotations it parses them into a %List of CVTerms and
- * when writing a model it parses the CVTerms into the appropriate annotation
- * structure.  This function creates a %CVTerm from the %XMLNode supplied.
- *
- * @param node an XMLNode_t representing a CVTerm_t.
- *
- * @return a pointer to the newly created CVTerm_t structure.
- *
- * @note this method assumes that the %XMLNode_t is of the correct form
- */
 LIBSBML_EXTERN
 CVTerm_t*
 CVTerm_createFromNode(const XMLNode_t *node)
@@ -494,11 +705,6 @@ CVTerm_createFromNode(const XMLNode_t *node)
 }
 
 
-/**
- * Frees the given CVTerm_t structure.
- *
- * @param term the CVTerm_t structure to be freed.
- */
 LIBSBML_EXTERN
 void
 CVTerm_free(CVTerm_t * term)
@@ -507,13 +713,6 @@ CVTerm_free(CVTerm_t * term)
   delete static_cast<CVTerm*>(term);
 }
 
-/**
- * Creates a deep copy of the given CVTerm_t structure
- * 
- * @param c the CVTerm_t structure to be copied
- * 
- * @return a (deep) copy of the given CVTerm_t structure.
- */
 LIBSBML_EXTERN
 CVTerm_t *
 CVTerm_clone (const CVTerm_t* c)
@@ -523,14 +722,6 @@ CVTerm_clone (const CVTerm_t* c)
 }
 
 
-/**
- * Takes a CVTerm_t structure and returns its #QualifierType_t type.
- *
- * @param term the CVTerm_t structure whose #QualifierType_t value is sought
- *
- * @return the #QualifierType_t value of this CVTerm_t or UNKNOWN_QUALIFIER
- * (default).
- */
 LIBSBML_EXTERN
 QualifierType_t 
 CVTerm_getQualifierType(CVTerm_t * term)
@@ -539,14 +730,6 @@ CVTerm_getQualifierType(CVTerm_t * term)
   return term->getQualifierType();
 }
 
-/**
- * Takes a CVTerm_t structure and returns the #ModelQualifierType_t type.
- *
- * @param term the CVTerm_t structure whose #ModelQualifierType_t is sought.
- *
- * @return the #ModelQualifierType_t value of this CVTerm_t or BQM_UNKNOWN
- * (default).
- */
 LIBSBML_EXTERN
 ModelQualifierType_t 
 CVTerm_getModelQualifierType(CVTerm_t * term)
@@ -555,15 +738,6 @@ CVTerm_getModelQualifierType(CVTerm_t * term)
   return term->getModelQualifierType();
 }
 
-/**
- * Takes a CVTerm_t structure and returns the #BiolQualifierType_t.
- *
- * @param term the CVTerm_t structure whose #BiolQualifierType_t value is
- * sought.
- *
- * @return the #BiolQualifierType_t value of this CVTerm_t or BQB_UNKNOWN
- * (default).
- */
 LIBSBML_EXTERN
 BiolQualifierType_t 
 CVTerm_getBiologicalQualifierType(CVTerm_t * term)
@@ -572,13 +746,6 @@ CVTerm_getBiologicalQualifierType(CVTerm_t * term)
   return term->getBiologicalQualifierType();
 }
 
-/**
- * Takes a CVTerm_t structure and returns the resources.
- * 
- * @param term the CVTerm_t structure whose resources are sought.
- *
- * @return the XMLAttributes_t that store the resources of this CVTerm_t.
- */
 LIBSBML_EXTERN
 XMLAttributes_t * 
 CVTerm_getResources(CVTerm_t * term)
@@ -587,14 +754,6 @@ CVTerm_getResources(CVTerm_t * term)
   return term->getResources();
 }
 
-/**
- * Returns the number of resources for this %CVTerm.
- *
- * @param term the CVTerm_t structure whose resources are sought.
- * 
- * @return the number of resources in the set of XMLAttributes
- * of this %CVTerm.
- */
 LIBSBML_EXTERN
 unsigned int
 CVTerm_getNumResources(CVTerm_t* term)
@@ -604,19 +763,6 @@ CVTerm_getNumResources(CVTerm_t* term)
 }
 
 
-/**
- * Returns the value of the nth resource for this %CVTerm.
- *
- * @param cv the CVTerm_t structure
- * @param n the index of the resource to query
- *
- * @return string representing the value of the nth resource
- * in the set of XMLAttributes of this %CVTerm.
- *
- * @note Since the values of the resource attributes in a CVTerm
- * are URIs this is a convenience function to facilitate
- * interaction with the CVTerm class.
- */
 LIBSBML_EXTERN
 char *
 CVTerm_getResourceURI(CVTerm_t * cv, unsigned int n)
@@ -626,19 +772,6 @@ CVTerm_getResourceURI(CVTerm_t * cv, unsigned int n)
 }
 
 
-/**
- * Sets the "QualifierType_t" of this %CVTerm_t.
- *
- * @param term the CVTerm_t structure to set.
- * @param type the QualifierType_t 
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_OBJECT
- */
 LIBSBML_EXTERN
 int 
 CVTerm_setQualifierType(CVTerm_t * term, QualifierType_t type)
@@ -648,23 +781,6 @@ CVTerm_setQualifierType(CVTerm_t * term, QualifierType_t type)
 }
 
 
-/**
- * Sets the "ModelQualifierType_t" of this %CVTerm.
- *
- * @param term the CVTerm_t structure to set.
- * @param type the ModelQualifierType_t
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT
- *
- * @note if the QualifierType for this object is not MODEL_QUALIFIER
- * then the ModelQualifierType will default to BQM_UNKNOWN.
- */
 LIBSBML_EXTERN
 int 
 CVTerm_setModelQualifierType(CVTerm_t * term, ModelQualifierType_t type)
@@ -674,23 +790,6 @@ CVTerm_setModelQualifierType(CVTerm_t * term, ModelQualifierType_t type)
 }
 
 
-/**
- * Sets the "BiolQualifierType_t" of this %CVTerm_t.
- *
- * @param term the CVTerm_t structure to set.
- * @param type the BiolQualifierType_t
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT
- *
- * @note if the QualifierType for this object is not BIOLOGICAL_QUALIFIER
- * then the BiolQualifierType_t will default to BQB_UNKNOWN.
- */
 LIBSBML_EXTERN
 int 
 CVTerm_setBiologicalQualifierType(CVTerm_t * term, BiolQualifierType_t type)
@@ -699,23 +798,6 @@ CVTerm_setBiologicalQualifierType(CVTerm_t * term, BiolQualifierType_t type)
   return term->setBiologicalQualifierType(type);
 }
 
-/**
- * Sets the "ModelQualifierType_t" of this %CVTerm.
- *
- * @param term the CVTerm_t structure to set.
- * @param qualifier the string representing a model qualifier
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT
- *
- * @note if the QualifierType for this object is not MODEL_QUALIFIER
- * then the ModelQualifierType will default to BQM_UNKNOWN.
- */
 LIBSBML_EXTERN
 int 
 CVTerm_setModelQualifierTypeByString(CVTerm_t * term, const char* qualifier)
@@ -728,23 +810,6 @@ CVTerm_setModelQualifierTypeByString(CVTerm_t * term, const char* qualifier)
 }
 
 
-/**
- * Sets the "BiolQualifierType_t" of this %CVTerm_t.
- *
- * @param term the CVTerm_t structure to set.
- * @param qualifier the string representing a biol qualifier
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT
- *
- * @note if the QualifierType for this object is not BIOLOGICAL_QUALIFIER
- * then the BiolQualifierType_t will default to BQB_UNKNOWN.
- */
 LIBSBML_EXTERN
 int 
 CVTerm_setBiologicalQualifierTypeByString(CVTerm_t * term, const char* qualifier)
@@ -756,23 +821,6 @@ CVTerm_setBiologicalQualifierTypeByString(CVTerm_t * term, const char* qualifier
     return term->setBiologicalQualifierType(qualifier);
 }
 
-/**
- * Adds a resource to the CVTerm_t.
- *
- * @param term the CVTerm_t structure to set.
- * @param resource string representing the resource 
- * e.g. http://www.geneontology.org/#GO:0005892
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_OPERATION_FAILED
- *
- * @note this method adds the name "rdf:resource" to the attribute prior
- * to adding it to the resources in this CVTerm.
- */
 LIBSBML_EXTERN
 int 
 CVTerm_addResource(CVTerm_t * term, const char * resource)
@@ -781,21 +829,6 @@ CVTerm_addResource(CVTerm_t * term, const char * resource)
   return term->addResource(resource);
 }
 
-/**
- * Removes a resource from the CVTerm_t.
- *
- * @param term the CVTerm_t structure.
- * @param resource string representing the resource 
- * e.g. http://www.geneontology.org/#GO:0005892
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- * @li LIBSBML_INVALID_OBJECT
- */
 LIBSBML_EXTERN
 int 
 CVTerm_removeResource(CVTerm_t * term, const char * resource)
@@ -814,6 +847,54 @@ CVTerm_hasRequiredAttributes(CVTerm_t *cvt)
 }
 
 
+LIBSBML_EXTERN
+unsigned int
+CVTerm_getNumNestedCVTerms(const CVTerm_t *cvt)
+{
+  if (cvt == NULL) return SBML_INT_MAX;
+  return cvt->getNumNestedCVTerms();
+}
+
+
+LIBSBML_EXTERN
+const CVTerm_t*
+CVTerm_getNestedCVTerm(const CVTerm_t *cvt, unsigned int n)
+{
+  if (cvt == NULL) return NULL;
+  return cvt->getNestedCVTerm(n);
+}
+
+
+
+LIBSBML_EXTERN
+int
+CVTerm_addNestedCVTerm(CVTerm_t *cvt, const CVTerm_t* term)
+{
+  if (cvt == NULL) return LIBSBML_INVALID_OBJECT;
+  return cvt->addNestedCVTerm(term);
+}
+
+
+
+LIBSBML_EXTERN
+CVTerm_t*
+CVTerm_removeNestedCVTerm(CVTerm_t *cvt, unsigned int n)
+{
+  if (cvt == NULL) return NULL;
+  return (CVTerm_t *)(cvt->removeNestedCVTerm(n));
+}
+
+
+
+LIBSBML_EXTERN
+const List_t*
+CVTerm_getListNestedCVTerms(const CVTerm_t *cvt)
+{
+  if (cvt == NULL) return NULL;
+  return cvt->getListNestedCVTerms();
+}
+
+
 
 static
 const char* MODEL_QUALIFIER_STRINGS[] =
@@ -821,6 +902,8 @@ const char* MODEL_QUALIFIER_STRINGS[] =
     "is"
   , "isDescribedBy"
   , "isDerivedFrom"
+  , "isInstanceOf"
+  , "hasInstance"
 };
 
 static
@@ -837,24 +920,11 @@ const char* BIOL_QUALIFIER_STRINGS[] =
   , "encodes"
   , "occursIn"
   , "hasProperty"
-  , "isPropertyOf"    
+  , "isPropertyOf"
+  , "hasTaxon"
 };
 
 
-/**
- * This method takes a model qualifier type code and returns a string 
- * representing the code.
- *
- * This method takes a model qualifier type as argument 
- * and returns a string name corresponding to that code.  For example, 
- * passing it the qualifier <code>BQM_IS_DESCRIBED_BY</code> will return 
- * the string "<code>isDescribedBy</code>". 
- *
- * @return a human readable qualifier name for the given type.
- *
- * @note The caller does not own the returned string and is therefore not
- * allowed to modify it.
- */
 LIBSBML_EXTERN
 const char* 
 ModelQualifierType_toString(ModelQualifierType_t type)
@@ -869,20 +939,6 @@ ModelQualifierType_toString(ModelQualifierType_t type)
   return MODEL_QUALIFIER_STRINGS[type];
 }
 
-/**
- * This method takes a biol qualifier type code and returns a string 
- * representing the code.
- *
- * This method takes a biol qualifier type as argument 
- * and returns a string name corresponding to that code.  For example, 
- * passing it the qualifier <code>BQB_HAS_VERSION</code> will return 
- * the string "<code>hasVersion</code>". 
- *
- * @return a human readable qualifier name for the given type.
- *
- * @note The caller does not own the returned string and is therefore not
- * allowed to modify it.
- */
 LIBSBML_EXTERN
 const char* 
 BiolQualifierType_toString(BiolQualifierType_t type)
@@ -897,18 +953,6 @@ BiolQualifierType_toString(BiolQualifierType_t type)
   return BIOL_QUALIFIER_STRINGS[type];
 }
 
-/**
- * This method takes a a string and returns a model qualifier
- * representing the string.
- *
- * This method takes a string as argument and returns a model qualifier type 
- * corresponding to that string.  For example, passing it the string 
- * "<code>isDescribedBy</code>" will return the qualifier 
- * <code>BQM_IS_DESCRIBED_BY</code>. 
- *
- * @return a qualifier for the given human readable qualifier name.
- *
- */
 LIBSBML_EXTERN
 ModelQualifierType_t 
 ModelQualifierType_fromString(const char* s)
@@ -924,18 +968,6 @@ ModelQualifierType_fromString(const char* s)
   return BQM_UNKNOWN;
 }
 
-/**
- * This method takes a a string and returns a biol qualifier
- * representing the string.
- *
- * This method takes a string as argument and returns a biol qualifier type 
- * corresponding to that string.  For example, passing it the string 
- * "<code>hasVersion</code>" will return the qualifier 
- * <code>BQB_HAS_VERSION</code>. 
- *
- * @return a qualifier for the given human readable qualifier name.
- *
- */
 LIBSBML_EXTERN
 BiolQualifierType_t 
 BiolQualifierType_fromString(const char* s)
