@@ -47,7 +47,7 @@
  * Format</a>).  The general scheme is as follows.  A set of RDF-based
  * annotations attached to a given SBML <code>&lt;annotation&gt;</code>
  * element are read by RDFAnnotationParser and converted into a list of
- * CVTerm objects.  There are different versions of the main method, @if clike RDFAnnotationParser::parseRDFAnnotation(const XMLNode *annotation, %List *CVTerms) @endif@if java RDFAnnotationParser::parseRDFAnnotation(const XMLNode *annotation, %CVTermList *CVTerms) @endif@~ and
+ * CVTerm objects.  There are different versions of the main method, @if clike RDFAnnotationParser::parseRDFAnnotation(const XMLNode *annotation, %List *CVTerms) @endif@if java RDFAnnotationParser::parseRDFAnnotation(XMLNode, %CVTermList) @endif@~ and
  * RDFAnnotationParser::parseRDFAnnotation(const XMLNode *annotation), used
  * depending on whether the annotation in question concerns the MIRIAM model
  * history or other MIRIAM resource annotations.  A special object class,
@@ -144,46 +144,46 @@ public:
    * is an SBML object derived from SBase (e.g., a Model, or a Species, or
    * a Compartment, etc.).  Then:@if clike
 @code{.cpp}
-int success;                              // Status code variable, used below.
+int success;                              // Status code variable.
 
-XMLNode *RDF = createRDFAnnotation();     // Create RDF annotation XML structure.
+XMLNode *RDF = createRDFAnnotation();     // Create XML structure.
 success = RDF->addChild(...content...);   // Put some content into it.
-...                                       // Check "success" return code value.
+...                                       // Check return code value.
 
-XMLNode *ann = createAnnotation();        // Create <annotation> container.
-success = ann->addChild(RDF);             // Put the RDF annotation into it.
-...                                       // Check "success" return code value.
+XMLNode *ann = createAnnotation();        // Create <annotation>.
+success = ann->addChild(RDF);             // Put the annotation into it.
+...                                       // Check return code value.
 
-success = sbmlObject->setAnnotation(ann); // Set object's annotation to what we built.
-...                                       // Check "success" return code value.
+success = sbmlObject->setAnnotation(ann); // Set object's annotation.
+...                                       // Check return code value.
 @endcode
    * @endif@if java
 @code{.java}
-int success;                                   // Status code variable, used below.
+int success;                                   // Status code variable.
 
-XMLNode RDF = createRDFAnnotation();          // Create RDF annotation XML structure.
+XMLNode RDF = createRDFAnnotation();          // Create XML structure.
 success      = RDF.addChild(...content...);    // Put some content into it.
-...                                            // Check "success" return code value.
+...                                            // Check return code value.
 
-XMLNode ann = createAnnotation();             // Create <annotation> container.
-success      = ann.addChild(RDF);              // Put the RDF annotation into it.
-...                                            // Check "success" return code value.
+XMLNode ann = createAnnotation();             // Create <annotation>.
+success      = ann.addChild(RDF);              // Put the annotation into it.
+...                                            // Check return code value.
 
-success      = sbmlObject.setAnnotation(ann); // Set object's annotation to what we built.
-...                                            // Check "success" return code value.
+success      = sbmlObject.setAnnotation(ann); // Set object's annotation.
+...                                            // Check return code value.
 @endcode
    * @endif@if python
 @code{.py}
-RDF     = RDFAnnotationParser.createRDFAnnotation() # Create RDF annotation XML structure.
+RDF     = RDFAnnotationParser.createRDFAnnotation() # Create XML structure.
 success = RDF.addChild(...content...)               # Put some content into it.
-...                                                 # Check "success" return code value.
+...                                                 # Check return code value.
 
-annot   = RDFAnnotationParser.createAnnotation()    # Create <annotation> container.
-success = annot.addChild(RDF)                       # Put the RDF annotation into it.
-...                                                 # Check "success" return code value.
+annot   = RDFAnnotationParser.createAnnotation()    # Create <annotation>.
+success = annot.addChild(RDF)                       # Put the annotation into it.
+...                                                 # Check return code value.
 
-success = sbmlObject.setAnnotation(annot)           # Set object's annotation to what we built.
-...                                                 # Check "success" return code value.
+success = sbmlObject.setAnnotation(annot)           # Set object's annotation.
+...                                                 # Check return code value.
 @endcode
    * @endif@~
    * The SBML specification contains more information about the format of
@@ -228,7 +228,8 @@ success = sbmlObject.setAnnotation(annot)           # Set object's annotation to
    *
    * @see @if clike createAnnotation() @else RDFAnnotationParser::createAnnotation() @endif@~
    */
-  static XMLNode * createRDFAnnotation();
+  static XMLNode * createRDFAnnotation(unsigned int level = 3, 
+                                       unsigned int version = 1);
 
 
   /**
@@ -432,7 +433,16 @@ success = sbmlObject.setAnnotation(annot)           # Set object's annotation to
   static XMLNode * createRDFDescriptionWithHistory(const SBase *obj);
 
 
-  static void deriveCVTermsFromAnnotation(const XMLNode *annotation, List *CVTerms);
+  static XMLNode * createBagElement(const CVTerm * term, unsigned int level,
+                                    unsigned int version);
+
+
+  static XMLNode * createQualifierElement(const CVTerm * term,
+                                   unsigned int level, unsigned int version);
+
+
+  static void deriveCVTermsFromAnnotation(const XMLNode *annotation, 
+                                          List *CVTerms);
 
   
   static ModelHistory* deriveHistoryFromAnnotation(const XMLNode *annotation);
@@ -525,6 +535,27 @@ RDFAnnotationParser_createAnnotation();
 XMLNode_t *
 RDFAnnotationParser_createRDFAnnotation();
 
+/**
+  * Creates blank RDF annotation content organized in the form defined in
+  * Section 6 of the SBML Level 2 Version 4 specification .
+  *
+  * The annotation created by this method has namespace declarations for
+  * all the relevant XML namespaces used in RDF annotations and also has
+  * an empty RDF element.  Note that this is not the containing
+  * <code>&lt;annotation&gt;</code> element; the method createAnnotation()
+  * is available for that purpose.
+  *
+  * @param level unsigned int giving the SBML level to target.
+  * @param version unsigned int giving the SBML version to target.
+  *
+  * @return a pointer to an XMLNode_t represting the annotation.
+  *
+  * @memberof RDFAnnotationParser_t
+  */
+XMLNode_t *
+RDFAnnotationParser_createRDFAnnotationForLevelAndVersion(unsigned int level,
+                                                         unsigned int version);
+
 /**
   * Deletes any RDF annotation found in the given XMLNode_t tree and returns
   * any remaining annotation content.
