@@ -74,7 +74,7 @@ SBMLConverter(orig)
 {
 }
 
-SBMLConverter* 
+SBMLRuleConverter* 
 SBMLRuleConverter::clone() const
 {
   return new SBMLRuleConverter(*this);
@@ -89,12 +89,22 @@ SBMLRuleConverter::~SBMLRuleConverter ()
 
 
 ConversionProperties
-  SBMLRuleConverter::getDefaultProperties() const
+SBMLRuleConverter::getDefaultProperties() const
 {
   static ConversionProperties prop;
-  prop.addOption("sortRules", true,
+  static bool init = false;
+
+  if (init) 
+  {
+    return prop;
+  }
+  else
+  {
+    prop.addOption("sortRules", true,
                  "Sort AssignmentRules and InitialAssignments in the model");
-  return prop;
+    init = true;
+    return prop;
+  }
 }
 
 bool 
@@ -323,7 +333,7 @@ SBMLRuleConverter::convert()
   if (mModel == NULL) return LIBSBML_INVALID_OBJECT;
 
   
-  /* if there are no function definitions and initial assignments bail now */
+  /* if there are no rules and initial assignments bail now */
   if (mModel->getNumRules() == 0 && mModel->getNumInitialAssignments() == 0)
   {
     return LIBSBML_OPERATION_SUCCESS;
