@@ -373,6 +373,7 @@ SBMLUnitsConverter::convertUnits(SBase &sb, Model &m,
    * until after the conversion is complete
    */
   bool conversion = false;
+  bool deleteUD = false;
 
   int tc = sb.getTypeCode();
 
@@ -486,6 +487,7 @@ SBMLUnitsConverter::convertUnits(SBase &sb, Model &m,
           Unit * u = ud->createUnit();
           u->initDefaults();
           u->setKind(UnitKind_forName(units.c_str()));
+          deleteUD = true;
         }
         else
         {
@@ -542,8 +544,14 @@ SBMLUnitsConverter::convertUnits(SBase &sb, Model &m,
       /* we are dealing in concentration 
       * but the unit of the species must be substance
       */
-      ud = UnitDefinition::combine(ud, ud_vol);
-      siud = UnitDefinition::convertToSI(ud);
+      UnitDefinition * tempud = UnitDefinition::combine(ud, ud_vol);
+      if (siud != NULL)
+      {
+        delete siud;
+        siud = NULL;
+      }
+      siud = UnitDefinition::convertToSI(tempud);
+      delete tempud;
     }
 
 
@@ -788,6 +796,9 @@ SBMLUnitsConverter::convertUnits(SBase &sb, Model &m,
   if (i == LIBSBML_OPERATION_SUCCESS)
     conversion = true;
 
+  if (siud != NULL) delete siud;
+  if (deleteUD == true) delete ud;
+
   return conversion;
 }
 /** @endcond */
@@ -1025,7 +1036,7 @@ SBMLUnitsConverter::applyNewUnitDefinition(SBase &sb, Model &m,
         {
           if (m.getUnitDefinition(newId) != NULL)
           {
-            m.removeUnitDefinition(newId);
+            delete m.removeUnitDefinition(newId);
           }
         }
         i = m.addUnitDefinition(newUD);
@@ -1455,7 +1466,7 @@ SBMLUnitsConverter::removeUnusedUnitDefinitions(Model& m)
     if (Unit::isBuiltIn(m.getUnitDefinition(i)->getId(), m.getLevel()) == false
       && (isUsed(m, m.getUnitDefinition(i)->getId()) == false))
     {
-      m.removeUnitDefinition(i);
+      delete m.removeUnitDefinition(i);
     }
   }
 
