@@ -9,9 +9,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -35,8 +40,7 @@
 #include <iostream>
 #include <string>
 
-#include "RegisterExtensions.h"
-
+#include <sbml/extension/RegisterExtensions.h>
 
 #ifdef __cplusplus
 
@@ -47,6 +51,8 @@ using namespace std;
 LIBSBML_CPP_NAMESPACE_BEGIN
 #ifdef __cplusplus
 
+
+/** @cond doxygenLibsbmlInternal */
 SBMLExtensionRegistry* SBMLExtensionRegistry::mInstance = NULL;
 
 bool SBMLExtensionRegistry::registered = false;
@@ -62,6 +68,9 @@ SBMLExtensionRegistry::deleteRegistry()
   }
 }
 
+/** @cond doxygenLibsbmlInternal */
+
+
 /*
  *
  */
@@ -77,7 +86,7 @@ SBMLExtensionRegistry::getInstance()
   if (!registered)
   {
     registered = true;
-    #include "RegisterExtensions.cxx"
+    #include <sbml/extension/RegisterExtensions.cxx>
   }
   return *mInstance;
 }
@@ -369,7 +378,7 @@ SBMLExtensionRegistry::removeL2Namespaces(XMLNamespaces *xmlns)  const
   }
 }
 
-/**
+/*
  * adds all L2 Extension namespaces to the namespace list. This will call all 
  * overriden SBMLExtension::addL2Namespaces methods.
  */
@@ -384,7 +393,7 @@ SBMLExtensionRegistry::addL2Namespaces(XMLNamespaces *xmlns) const
   }
 }
 
-/**
+/*
  * Enables all extensions that support serialization / deserialization with
  * SBML Annotations.
  */
@@ -413,6 +422,11 @@ SBMLExtensionRegistry::isEnabled(const std::string& uri)
   return (sbmlext) ? sbmlext->mIsEnabled : false;
 }
 
+void DeleteStringChild(void* child)
+{
+  if (child == NULL) return;
+  free ((char*)child);
+}
 
 /*
  * Checks if the extension with the given URI is registered (true) or not (false)
@@ -429,32 +443,69 @@ SBMLExtensionRegistry::getRegisteredPackageNames()
   const SBMLExtensionRegistry& instance = getInstance();
   SBMLExtensionMap::const_iterator it = instance.mSBMLExtensionMap.begin();
   List* result = new List();
-  IdList  * present = new IdList();
+  std::vector<std::string> present;
   while (it != instance.mSBMLExtensionMap.end())
   {    
-    if (present->contains((*it).second->getName().c_str()) == false)
+    const std::string& temp = (*it).second->getName();
+    if (std::find(present.begin(), present.end(), temp) == present.end())
     {
-      result->add(safe_strdup((*it).second->getName().c_str()));
-      present->append(safe_strdup((*it).second->getName().c_str()));
+      char *name = safe_strdup(temp.c_str());
+      result->add(name);
+      present.push_back(temp);
     }
     it++;
   }
-  delete present;
+  
+  return result;
+}
+
+std::vector<std::string> SBMLExtensionRegistry::getAllRegisteredPackageNames()
+{
+  const SBMLExtensionRegistry& instance = getInstance();
+  std::vector<std::string> result;
+  SBMLExtensionMap::const_iterator it = instance.mSBMLExtensionMap.begin();
+  while (it != instance.mSBMLExtensionMap.end())
+  {    
+    const std::string& temp = (*it).second->getName();
+    if (std::find(result.begin(), result.end(), temp) == result.end())
+    {
+      result.push_back(temp);
+    }
+    ++it;
+  }
   return result;
 }
 
 unsigned int 
 SBMLExtensionRegistry::getNumRegisteredPackages()
 {
-  return (unsigned int) getRegisteredPackageNames()->getSize();
+   return (unsigned int)getAllRegisteredPackageNames().size();
 }
 
 
 std::string
 SBMLExtensionRegistry::getRegisteredPackageName(unsigned int index)
 {
-  char * name = (char *) (getRegisteredPackageNames()->get(index));
-  return string(name);
+  const SBMLExtensionRegistry& instance = getInstance();
+  SBMLExtensionMap::const_iterator it = instance.mSBMLExtensionMap.begin();
+  std::vector<std::string> present;
+  unsigned int count = 0;
+  while (it != instance.mSBMLExtensionMap.end())
+  {    
+    const std::string& temp = (*it).second->getName();
+    if (std::find(present.begin(), present.end(), temp) == present.end())
+    {
+      if (index == count)
+      {
+        return temp;
+      }
+      present.push_back(temp);
+      ++count;
+    }
+    ++it;
+  }
+
+  return "";
 }
 
 void 
@@ -471,7 +522,7 @@ SBMLExtensionRegistry::disableUnusedPackages(SBMLDocument *doc)
 }
 
 
-/**
+/*
  * Disables the package with the given URI / name.
  */
 void
@@ -483,7 +534,7 @@ SBMLExtensionRegistry::disablePackage(const std::string& package)
 }
 
 /** @cond doxygenLibsbmlInternal */
-/**
+/*
  * Disables all packages with the given URI / name.
  */
 void
@@ -498,7 +549,7 @@ SBMLExtensionRegistry::disablePackages(const std::vector<std::string>& packages)
 }
 /** @endcond */
 
-/**
+/*
  * Enables the package with the given URI / name.
  */
 void
@@ -509,7 +560,7 @@ SBMLExtensionRegistry::enablePackage(const std::string& package)
     ext->setEnabled(true);  
 }
 
-/**
+/*
  * @returns the status (enabled = <b>true</b>, disabled = <b>false</b> of the given package.
  */
 bool
@@ -522,7 +573,7 @@ SBMLExtensionRegistry::isPackageEnabled(const std::string& package)
 }
 
 /** @cond doxygenLibsbmlInternal */
-/**
+/*
  * Enables all packages with the given URI / name.
  */
 void
@@ -540,20 +591,9 @@ SBMLExtensionRegistry::enablePackages(const std::vector<std::string>& packages)
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 
-/**
- * Add the given SBMLExtension_t to the SBMLExtensionRegistry.
- *
- * @param SBMLExtension the SBMLExtension_t structure to be added.
- *   
- * @return integer value indicating success/failure of the
- * function.  The possible values returned by this function are:
- * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS @endlink
- * @li @link OperationReturnValues_t#LIBSBML_PKG_CONFLICT LIBSBML_PKG_CONFLICT @endlink
- * @li @link OperationReturnValues_t#LIBSBML_INVALID_ATTRIBUTE_VALUE LIBSBML_INVALID_ATTRIBUTE_VALUE @endlink
- */
 LIBSBML_EXTERN
 int 
 SBMLExtensionRegistry_addExtension(const SBMLExtension_t* extension)
@@ -562,16 +602,6 @@ SBMLExtensionRegistry_addExtension(const SBMLExtension_t* extension)
   return SBMLExtensionRegistry::getInstance().addExtension(extension);
 }
 
-/**
- * Returns an SBMLExtension_t structure with the given package URI or package name (string).
- *
- * @param package the URI or name of the package extension
- *
- * @return a clone of the SBMLExtension object with the given package URI or name. 
- * Or NULL in case of an invalid package name.
- * 
- * @note The returned extension is to be freed (i.e.: deleted) by the caller!
- */
 LIBSBML_EXTERN
 SBMLExtension_t* 
 SBMLExtensionRegistry_getExtension(const char* package)
@@ -581,17 +611,6 @@ SBMLExtensionRegistry_getExtension(const char* package)
   return SBMLExtensionRegistry::getInstance().getExtension(sPackage);
 }
 
-/**
- * Returns an SBasePluginCreator_t structure with the combination of the given 
- * extension point and URI of the package extension.
- *
- * @param extPoint the SBaseExtensionPoint
- * @param uri the URI of the target package extension.
- *
- * @return the SBasePluginCreator_t with the combination of the given 
- * SBMLTypeCode_t and the given URI of package extension, or @c NULL for 
- * invalid extensionPoint or uri.
- */
 LIBSBML_EXTERN
 const SBasePluginCreatorBase_t* 
 SBMLExtensionRegistry_getSBasePluginCreator(const SBaseExtensionPoint_t* extPoint, const char* uri)
@@ -601,14 +620,6 @@ SBMLExtensionRegistry_getSBasePluginCreator(const SBaseExtensionPoint_t* extPoin
   return SBMLExtensionRegistry::getInstance().getSBasePluginCreator(*extPoint, sUri);
 }
 
-/**
- * Returns a copied array of SBasePluginCreators with the given extension point.
- *
- * @param extPoint the SBaseExtensionPoint
- * @param length pointer to a variable holding the length of the array returned. 
- *
- * @return an array of SBasePluginCreators with the given typecode.
- */
 LIBSBML_EXTERN
 SBasePluginCreatorBase_t**
 SBMLExtensionRegistry_getSBasePluginCreators(const SBaseExtensionPoint_t* extPoint, int* length)
@@ -631,16 +642,6 @@ SBMLExtensionRegistry_getSBasePluginCreators(const SBaseExtensionPoint_t* extPoi
   return result;
 }
 
-/**
- * Returns a copied array of SBasePluginCreators with the given URI
- * of package extension.
- *
- * @param uri the URI of the target package extension.
- * @param length pointer to a variable holding the length of the array returned. 
- *
- * @return an array of SBasePluginCreators with the given URI
- * of package extension to be freed by the caller.
- */
 LIBSBML_EXTERN
 SBasePluginCreatorBase_t**
 SBMLExtensionRegistry_getSBasePluginCreatorsByURI(const char* uri, int* length)
@@ -664,15 +665,6 @@ SBMLExtensionRegistry_getSBasePluginCreatorsByURI(const char* uri, int* length)
 }
 
 
-/**
- * Checks if the extension with the given URI is enabled (true) or 
- * disabled (false)
- *
- * @param uri the URI of the target package.
- *
- * @return false (0) will be returned if the given package is disabled 
- * or not registered, otherwise true (1) will be returned.
- */
 LIBSBML_EXTERN
 int
 SBMLExtensionRegistry_isEnabled(const char* uri)
@@ -682,17 +674,6 @@ SBMLExtensionRegistry_isEnabled(const char* uri)
   return SBMLExtensionRegistry::getInstance().isEnabled(sUri);
 }
 
-/**
- * Enable/disable the package with the given uri.
- *
- * @param uri the URI of the target package.
- * @param isEnabled the bool value corresponding to enabled (true/1) or 
- * disabled (false/0)
- *
- * @return false (0) will be returned if the given bool value is false 
- * or the given package is not registered, otherwise true (1) will be
- * returned.
- */
 LIBSBML_EXTERN
 int
 SBMLExtensionRegistry_setEnabled(const char* uri, int isEnabled)
@@ -702,15 +683,6 @@ SBMLExtensionRegistry_setEnabled(const char* uri, int isEnabled)
   return SBMLExtensionRegistry::getInstance().setEnabled(sUri, isEnabled);
 }
 
-/**
- * Checks if the extension with the given URI is registered (true/1) 
- * or not (false/0)
- *
- * @param uri the URI of the target package.
- *
- * @return true (1) will be returned if the package with the given URI
- * is registered, otherwise false (0) will be returned.
- */
 LIBSBML_EXTERN
 int
 SBMLExtensionRegistry_isRegistered(const char* uri)
@@ -720,13 +692,6 @@ SBMLExtensionRegistry_isRegistered(const char* uri)
   return (int)SBMLExtensionRegistry::getInstance().isRegistered(sUri);
 }
 
-/**
- * Returns the number of SBMLExtension_t structures for the given extension point.
- *
- * @param extPoint the SBaseExtensionPoint
- *
- * @return the number of SBMLExtension_t structures for the given extension point.
- */
 LIBSBML_EXTERN
 int 
 SBMLExtensionRegistry_getNumExtensions(const SBaseExtensionPoint_t* extPoint)
@@ -736,12 +701,6 @@ SBMLExtensionRegistry_getNumExtensions(const SBaseExtensionPoint_t* extPoint)
 }
 
 
-/** 
- * Returns a list of registered packages (such as 'layout', 'fbc' or 'comp')
- * the list contains char* strings and has to be freed by the caller. 
- * 
- * @return the names of the registered packages in a list
- */
 LIBSBML_EXTERN
 List_t*
 SBMLExtensionRegistry_getRegisteredPackages()
