@@ -134,7 +134,7 @@ public:
    *
    * @return the value of the "arrayDimension" attribute of this Index as a unsigned integer.
    */
-  virtual const unsigned int getArrayDimension() const;
+  virtual unsigned int getArrayDimension() const;
 
 
   /**
