@@ -7,8 +7,15 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright 2011 California Institute of Technology.
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
  * 
+ * Copyright 2011-2012 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.  A copy of the license agreement is provided
@@ -47,11 +54,10 @@ Replacing::Replacing (unsigned int level, unsigned int version, unsigned int pkg
 
 
 Replacing::Replacing(CompPkgNamespaces* compns)
-  : SBaseRef(compns)
+  : SBaseRef(compns, true)
   , mSubmodelRef("")
   , mConversionFactor("")
 {
-  loadPlugins(compns);
 }
 
 
@@ -331,7 +337,7 @@ Replacing::replaceWithAndMaybeDelete(SBase* replacement, bool deleteme, ASTNode*
   if (ret != LIBSBML_OPERATION_SUCCESS) return ret;
 
   //Perform any conversions on references in the submodel.
-  ret = performConversions(replacement, conversionFactor);
+  ret = performConversions(replacement, &conversionFactor);
   if (ret != LIBSBML_OPERATION_SUCCESS) return ret;
 
   //Finally, recurse down if there are things the replaced element itself replaced (or used to be replaced by)
@@ -426,13 +432,14 @@ Replacing::updateIDs(SBase* oldnames, SBase* newnames)
     }
   }
   //LS DEBUG And here is where we would need some sort of way to check for ids that were not 'id' or 'metaid'.
+  delete allElements;
   return ret;
 }
 /** @endcond */
 
 
 /** @cond doxygenLibsbmlInternal */
-int Replacing::performConversions(SBase* replacement, ASTNode*& conversionFactor)
+int Replacing::performConversions(SBase* replacement, ASTNode** conversionFactor)
 {
   SBMLDocument* doc = getSBMLDocument();
   int ret = convertConversionFactor(conversionFactor);
@@ -440,7 +447,7 @@ int Replacing::performConversions(SBase* replacement, ASTNode*& conversionFactor
     //convertConversionFactor sets its own error messages.
     return ret;
   }
-  if (conversionFactor==NULL) {
+  if (*conversionFactor==NULL) {
     return ret;
   }
   if (replacement==NULL) {
@@ -477,42 +484,43 @@ int Replacing::performConversions(SBase* replacement, ASTNode*& conversionFactor
   replacementAST.setName(id.c_str());
   ASTNode divide(AST_DIVIDE);
   divide.addChild(replacementAST.deepCopy());
-  divide.addChild(conversionFactor->deepCopy());
+  divide.addChild((*conversionFactor)->deepCopy());
   List* allElements = replacedmod->getAllElements();
   for (unsigned int e=0; e<allElements->getSize(); e++) {
     SBase* element = static_cast<SBase*>(allElements->get(e));
     element->replaceSIDWithFunction(id, &divide);
-    element->multiplyAssignmentsToSIdByFunction(id, conversionFactor);
+    element->multiplyAssignmentsToSIdByFunction(id, *conversionFactor);
   }
+  delete allElements;
   return ret;
 }
 /** @endcond */
 
 
 /** @cond doxygenLibsbmlInternal */
-int Replacing::convertConversionFactor(ASTNode*& conversionFactor)
+int Replacing::convertConversionFactor(ASTNode** conversionFactor)
 {
   int ret = LIBSBML_OPERATION_SUCCESS;
   ASTNode* newCF = NULL;
   if (mConversionFactor=="") {
-    newCF = conversionFactor;
+    //newCF = *conversionFactor;
   }
   else {
     ASTNode factor(AST_NAME);
     factor.setName(mConversionFactor.c_str());
-    if (conversionFactor==NULL) {
+    if (*conversionFactor==NULL) {
       newCF = new ASTNode(factor);
-      conversionFactor = newCF;
+      *conversionFactor = newCF;
     }
-    else if (conversionFactor->getType()==AST_NAME) {
+    else if ((*conversionFactor)->getType()==AST_NAME) {
       newCF = new ASTNode(AST_TIMES);
-      newCF->addChild(conversionFactor);
-      newCF->addChild(&factor);
-      conversionFactor = newCF;
+      newCF->addChild(*conversionFactor);
+      newCF->addChild(factor.deepCopy());
+      *conversionFactor = newCF;
     }
-    else if (conversionFactor->getType()==AST_TIMES) {
-      conversionFactor->addChild(factor.deepCopy());
-      newCF = conversionFactor;
+    else if ((*conversionFactor)->getType()==AST_TIMES) {
+      (*conversionFactor)->addChild(factor.deepCopy());
+      //newCF = *conversionFactor;
     }
     else {
       SBMLDocument* doc = getSBMLDocument();
