@@ -159,10 +159,6 @@ protected:
   Model*        mInstantiatedModel;
   std::string   mInstantiationOriginalURI;
 
-#ifndef SWIG
-  static std::vector<ModelProcessingCallbackData*> mProcessingCBs;
-#endif
-
   /** @endcond */
 
 public:
@@ -719,9 +715,10 @@ public:
    *
    * @copydetails doc_returns_success_code
    * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
-   * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t} (which
+   * indicates this Submodel itself is invalid, and no Model can be instantiated
+   * from it)
    * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
-   * In this case, 'invalid object' means that this Submodel itself is invalid, and no Model can be instantiated from it.
    */
   virtual int instantiate();
 
@@ -732,9 +729,10 @@ public:
    *
    * @copydetails doc_returns_success_code
    * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
-   * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t} (which
+   * indicates this Submodel itself is invalid, and no Model can be instantiated
+   * from it)
    * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
-   * In this case, 'invalid object' means that this Submodel itself is invalid, and no Model can be instantiated from it.
    */
   virtual int performDeletions();
 
