@@ -6,9 +6,16 @@
  *<!---------------------------------------------------------------------------
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
- *
- * Copyright 2009-2013 California Institute of Technology.
  * 
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
+ * Copyright (C) 2009-2013 jointly by the following organizations: 
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.  A copy of the license agreement is provided
@@ -263,7 +270,7 @@ FluxObjective::unsetReaction ()
 /*
   * Returns the value of the "coefficient" attribute of this FluxObjective.
   */
-const double 
+double 
 FluxObjective::getCoefficient () const
 {
   return mCoefficient;
@@ -691,6 +698,7 @@ ListOfFluxObjectives::createObject (XMLInputStream& stream)
       FBC_CREATE_NS(fbcns, getSBMLNamespaces());
       object = new FluxObjective(fbcns);
       appendAndOwn(object);
+      delete fbcns;
       //mItems.push_back(object);
     } 
     catch(...)
@@ -711,11 +719,8 @@ ListOfFluxObjectives::createObject (XMLInputStream& stream)
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
-/**
- *
- */
 LIBSBML_EXTERN
 FluxObjective_t *
 FluxObjective_create(unsigned int level, unsigned int version, unsigned int pkgversion)
@@ -724,9 +729,6 @@ FluxObjective_create(unsigned int level, unsigned int version, unsigned int pkgv
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 const char *
 FluxObjective_getId(FluxObjective_t * fb)
@@ -738,9 +740,6 @@ FluxObjective_getId(FluxObjective_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxObjective_isSetId(FluxObjective_t * fb)
@@ -749,9 +748,6 @@ FluxObjective_isSetId(FluxObjective_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxObjective_setId(FluxObjective_t * fb, const char * id)
@@ -760,9 +756,6 @@ FluxObjective_setId(FluxObjective_t * fb, const char * id)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxObjective_unsetId(FluxObjective_t * fb)
@@ -770,9 +763,6 @@ FluxObjective_unsetId(FluxObjective_t * fb)
   return (fb != NULL) ? fb->unsetId() : LIBSBML_INVALID_OBJECT;
 }
 
-/**
- *
- */
 LIBSBML_EXTERN
 const char *
 FluxObjective_getName(FluxObjective_t * fb)
@@ -782,9 +772,6 @@ FluxObjective_getName(FluxObjective_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxObjective_isSetName(FluxObjective_t * fb)
@@ -794,9 +781,6 @@ FluxObjective_isSetName(FluxObjective_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxObjective_setName(FluxObjective_t * fb, const char * name)
@@ -806,9 +790,6 @@ FluxObjective_setName(FluxObjective_t * fb, const char * name)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxObjective_unsetName(FluxObjective_t * fb)
@@ -820,9 +801,6 @@ FluxObjective_unsetName(FluxObjective_t * fb)
 
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 const char *
 FluxObjective_getReaction(FluxObjective_t * flux)
@@ -834,9 +812,6 @@ FluxObjective_getReaction(FluxObjective_t * flux)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxObjective_isSetReaction(FluxObjective_t * flux)
@@ -845,9 +820,6 @@ FluxObjective_isSetReaction(FluxObjective_t * flux)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxObjective_setReaction(FluxObjective_t * flux, const char * reaction)
@@ -856,9 +828,6 @@ FluxObjective_setReaction(FluxObjective_t * flux, const char * reaction)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxObjective_unsetReaction(FluxObjective_t * flux)
@@ -867,9 +836,6 @@ FluxObjective_unsetReaction(FluxObjective_t * flux)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 double
 FluxObjective_getCoefficient(FluxObjective_t * flux)
@@ -878,9 +844,6 @@ FluxObjective_getCoefficient(FluxObjective_t * flux)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxObjective_isSetCoefficient(FluxObjective_t * flux)
@@ -889,9 +852,6 @@ FluxObjective_isSetCoefficient(FluxObjective_t * flux)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxObjective_setCoefficient(FluxObjective_t * flux, double coeff)
@@ -900,9 +860,6 @@ FluxObjective_setCoefficient(FluxObjective_t * flux, double coeff)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxObjective_unsetCoefficient(FluxObjective_t * flux)
