@@ -12,7 +12,7 @@
  *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -277,7 +277,7 @@ Group::setKind(const GroupKind_t kind)
 /*
  * @return the kind of this SBML object.
  */
-const GroupKind_t
+GroupKind_t
 Group::getKind () const
 {
   return mKind;
@@ -443,6 +443,7 @@ Group::createMember ()
   {
     GROUPS_CREATE_NS(groupsns, getSBMLNamespaces());
     m = new Member(groupsns);
+    delete groupsns;
   }
   catch (...)
   {
@@ -599,6 +600,7 @@ Group::createMemberConstraint()
   {
     GROUPS_CREATE_NS(groupsns, getSBMLNamespaces());
     mc = new MemberConstraint(groupsns);
+    delete groupsns;
   }
   catch (...)
   {
@@ -1105,6 +1107,7 @@ ListOfGroups::createObject (XMLInputStream& stream)
     GROUPS_CREATE_NS(groupsns, this->getSBMLNamespaces());
     object = new Group(groupsns);
     appendAndOwn(object);
+    delete groupsns;
     //mItems.push_back(object);
   }
 
@@ -1121,7 +1124,8 @@ ListOfGroups::writeXMLNS (XMLOutputStream& stream) const
 
   if (prefix.empty())
   {
-    if (getNamespaces()->hasURI(GroupsExtension::getXmlnsL3V1V1()))
+    XMLNamespaces* thisxmlns = getNamespaces();
+    if (thisxmlns && thisxmlns->hasURI(GroupsExtension::getXmlnsL3V1V1()))
     {
       xmlns.add(GroupsExtension::getXmlnsL3V1V1(),prefix);
     }
