@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2004-2008 by European Media Laboratories Research gGmbH,
  *     Heidelberg, Germany
@@ -617,7 +622,7 @@ BoundingBox::createObject (XMLInputStream& stream)
     if (getDimensionsExplicitlySet() == true)
     {
       getErrorLog()->logPackageError("layout", LayoutBBoxAllowedElements, 
-          getPackageVersion(), getLevel(), getVersion());
+          getPackageVersion(), getLevel(), getVersion(), "", getLine(), getColumn());
     }
     object = &mDimensions;
     mDimensionsExplicitlySet = true;
@@ -628,7 +633,7 @@ BoundingBox::createObject (XMLInputStream& stream)
     if (getPositionExplicitlySet() == true)
     {
       getErrorLog()->logPackageError("layout", LayoutBBoxAllowedElements, 
-          getPackageVersion(), getLevel(), getVersion());
+          getPackageVersion(), getLevel(), getVersion(), "", getLine(), getColumn());
     }
       object = &mPosition;
       mPositionExplicitlySet = true;
@@ -671,7 +676,7 @@ void BoundingBox::readAttributes (const XMLAttributes& attributes,
 				                  getErrorLog()->getError(n)->getMessage();
 				getErrorLog()->remove(UnknownPackageAttribute);
 				getErrorLog()->logPackageError("layout", LayoutBBoxAllowedAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				               getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
 			}
 			else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
 			{
@@ -680,7 +685,7 @@ void BoundingBox::readAttributes (const XMLAttributes& attributes,
 				getErrorLog()->remove(UnknownCoreAttribute);
 				getErrorLog()->logPackageError("layout", 
                        LayoutBBoxAllowedCoreAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				               getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
 			}
 		}
 	}
@@ -806,13 +811,8 @@ BoundingBox::enablePackageInternal(const std::string& pkgURI,
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
-/**
- * Function that creates a BoundingBox_t object with position set to
- * (0.0,0.0,0.0) and dimensions set to (0.0,0.0,0.0). The id is set to the
- * empty string.
- */
 LIBSBML_EXTERN
 BoundingBox_t *
 BoundingBox_create (void)
@@ -821,11 +821,6 @@ BoundingBox_create (void)
 }
 
 
-/**
- * Function that creates a BoundingBox_t object with position set to
- * (0.0,0.0,0.0) and dimensions set to (0.0,0.0,0.0).  The id is set to the
- * given string.
- */
 LIBSBML_EXTERN
 BoundingBox_t *
 BoundingBox_createWith (const char *id)
@@ -835,10 +830,6 @@ BoundingBox_createWith (const char *id)
 }
 
 
-/**
- * Function that creates a BoundingBox_t object with the coordinates and
- * sizes given as arguments. The id is set to the empty string.
- */ 
 LIBSBML_EXTERN
 BoundingBox_t *
 BoundingBox_createWithCoordinates (const char *id,
@@ -850,9 +841,6 @@ BoundingBox_createWithCoordinates (const char *id,
 }
 
 
-/**
- * Frees all memory taken by the given BoundingBox_t object.
- */ 
 LIBSBML_EXTERN
 void
 BoundingBox_free (BoundingBox_t *bb)
@@ -861,231 +849,187 @@ BoundingBox_free (BoundingBox_t *bb)
 }
 
 
-/**
- * Does nothing since no defaults are defined for BoundingBox.
- */
 LIBSBML_EXTERN
 void
 BoundingBox_initDefaults (BoundingBox_t *bb)
 {
+  if (bb == NULL) return;
   bb->initDefaults();
 }
 
 
-/**
- * Returns the position as a Point_t object.
- */ 
 LIBSBML_EXTERN
 Point_t *
 BoundingBox_getPosition (BoundingBox_t *bb)
 {
+  if (bb == NULL) return NULL;
   return bb->getPosition();
 }
 
 
-/**
- * Returns the dimensions as a Dimensions_t object.
- */ 
 LIBSBML_EXTERN
 Dimensions_t *
 BoundingBox_getDimensions (BoundingBox_t *bb)
 {
+  if (bb == NULL) return NULL;
   return bb->getDimensions();
 }
 
 
-/**
- * Sets the position to a copy of the Point_t object given as argument.
- */
 LIBSBML_EXTERN
 void
 BoundingBox_setPosition (BoundingBox_t *bb, const Point_t *p)
 {
-   bb->setPosition(p);
+  if (bb == NULL) return;
+  bb->setPosition(p);
 }
 
 
-/**
- * Sets the dimensions to a copy of the Dimensions_t object given.
- */ 
 LIBSBML_EXTERN
 void
 BoundingBox_setDimensions (BoundingBox_t *bb, const Dimensions_t *d)
 {
+  if (bb == NULL) return;
   bb->setDimensions(d);
 }
 
-/**
- * Sets the x offset of the bounding box.
- */
 LIBSBML_EXTERN
 void
 BoundingBox_setX(BoundingBox_t* bb,double x)
 {
-    bb->setX(x);
+  if (bb == NULL) return;
+  bb->setX(x);
 }
 
-/**
- * Sets the y offset of the bounding box.
- */
 LIBSBML_EXTERN
 void
 BoundingBox_setY(BoundingBox_t* bb,double y)
 {
-    bb->setY(y);
+  if (bb == NULL) return;
+  bb->setY(y);
 }
 
 
-/**
- * Sets the z offset of the bounding box.
- */
 LIBSBML_EXTERN
 void
 BoundingBox_setZ(BoundingBox_t* bb,double z)
 {
-    bb->setZ(z);
+  if (bb == NULL) return;
+  bb->setZ(z);
 }
 
 
-/**
- * Sets the width of the bounding box.
- */
 LIBSBML_EXTERN
 void
 BoundingBox_setWidth(BoundingBox_t* bb,double width)
 {
-    bb->setWidth(width);
+  if (bb == NULL) return;
+  bb->setWidth(width);
 }
 
 
-/**
- * Sets the height of the bounding box.
- */
 LIBSBML_EXTERN
 void
 BoundingBox_setHeight(BoundingBox_t* bb,double height)
 {
-    bb->setHeight(height);
+  if (bb == NULL) return;
+  bb->setHeight(height);
 }
 
 
-/**
- * Sets the depth of the bounding box.
- */
 LIBSBML_EXTERN
 void
 BoundingBox_setDepth(BoundingBox_t* bb,double depth)
 {
-    bb->setDepth(depth);
+  if (bb == NULL) return;
+  bb->setDepth(depth);
 }
 
-/**
- * Returns the x offset of the bounding box
- */
 LIBSBML_EXTERN
 double
 BoundingBox_x(BoundingBox_t* bb)
 {
-    return bb->x();
+  if (bb == NULL) return std::numeric_limits<double>::quiet_NaN();
+  return bb->x();
 }
 
-/**
- * Returns the y offset of the bounding box
- */
 LIBSBML_EXTERN
 double
 BoundingBox_y(BoundingBox_t* bb)
 {
-    return bb->y();
+  if (bb == NULL) return std::numeric_limits<double>::quiet_NaN();
+  return bb->y();
 }
 
-/**
- * Returns the z offset of the bounding box
- */
 LIBSBML_EXTERN
 double
 BoundingBox_z(BoundingBox_t* bb)
 {
-    return bb->z();
+  if (bb == NULL) return std::numeric_limits<double>::quiet_NaN();
+  return bb->z();
 }
 
-/**
- * Returns the width of the bounding box
- */
 LIBSBML_EXTERN
 double
 BoundingBox_width(BoundingBox_t* bb)
 {
-    return bb->width();
+  if (bb == NULL) return std::numeric_limits<double>::quiet_NaN();
+  return bb->width();
 }
 
-/**
- * Returns the height of the bounding box
- */
 LIBSBML_EXTERN
 double
 BoundingBox_height(BoundingBox_t* bb)
 {
-    return bb->height();
+  if (bb == NULL) return std::numeric_limits<double>::quiet_NaN();
+  return bb->height();
 }
 
-/**
- * Returns the depth of the bounding box
- */
 LIBSBML_EXTERN
 double
 BoundingBox_depth(BoundingBox_t* bb)
 {
-    return bb->depth();
+  if (bb == NULL) return std::numeric_limits<double>::quiet_NaN();
+  return bb->depth();
 }
 
-/**
- * @return a (deep) copy of this BoundingBox.
- */
 LIBSBML_EXTERN
 BoundingBox_t *
 BoundingBox_clone (const BoundingBox_t *m)
 {
+  if (m == NULL) return NULL;
   return static_cast<BoundingBox*>( m->clone() );
 }
 
-/**
- * Returns non-zero if the id is set
- */
 LIBSBML_EXTERN
 int
 BoundingBox_isSetId (const BoundingBox_t *bb)
 {
+  if (bb == NULL) return (int)false;
   return static_cast <int> (bb->isSetId());
 }
 
-/**
- * Returns the id
- */
 LIBSBML_EXTERN
 const char *
 BoundingBox_getId (const BoundingBox_t *bb)
 {
+  if (bb == NULL) return NULL;
   return bb->isSetId() ? bb->getId().c_str() : NULL;
 }
 
-/**
- * Sets the id
- */
 LIBSBML_EXTERN
 int
 BoundingBox_setId (BoundingBox_t *bb, const char *sid)
 {
+  if (bb == NULL) return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   return (sid == NULL) ? bb->setId("") : bb->setId(sid);
 }
 
-/**
- * Unsets the id
- */
 LIBSBML_EXTERN
 void
 BoundingBox_unsetId (BoundingBox_t *bb)
 {
+  if (bb == NULL) return;
   bb->unsetId();
 }
 
