@@ -113,58 +113,17 @@ Dimensions::Dimensions(const Dimensions& orig)
     this->mW=orig.mW;
     this->mD=orig.mD;
     this->mDExplicitlySet=orig.mDExplicitlySet;
-    // attributes of SBase
-//    this->mId=orig.mId;
-//    this->mName=orig.mName;
-    this->mMetaId=orig.mMetaId;
-    if(orig.mNotes) this->mNotes=new XMLNode(*const_cast<Dimensions&>(orig).getNotes());
-    if(orig.mAnnotation) this->mAnnotation=new XMLNode(*const_cast<Dimensions&>(orig).mAnnotation);
-    this->mSBML=orig.mSBML;
-    this->mSBOTerm=orig.mSBOTerm;
-    this->mLine=orig.mLine;
-    this->mColumn=orig.mColumn;
-
-    if(orig.mCVTerms)
-    {
-      this->mCVTerms=new List();
-      unsigned int i,iMax=orig.mCVTerms->getSize();
-      for(i=0;i<iMax;++i)
-      {
-        this->mCVTerms->add(static_cast<CVTerm*>(orig.mCVTerms->get(i))->clone());
-      }
-    }
 }
 
 Dimensions& Dimensions::operator=(const Dimensions& orig)
 {
   if(&orig!=this)
   {
+    SBase::operator=(orig);
     this->mH=orig.mH;
     this->mW=orig.mW;
     this->mD=orig.mD;
     this->mDExplicitlySet=orig.mDExplicitlySet;
-    this->mMetaId=orig.mMetaId;
-    delete this->mNotes;
-    this->mNotes=NULL;
-    if(orig.mNotes) this->mNotes=new XMLNode(*const_cast<Dimensions&>(orig).getNotes());
-    delete this->mAnnotation;
-    this->mAnnotation=NULL;
-    if(orig.mAnnotation) this->mAnnotation=new XMLNode(*const_cast<Dimensions&>(orig).mAnnotation);
-    this->mSBML=orig.mSBML;
-    this->mSBOTerm=orig.mSBOTerm;
-    this->mLine=orig.mLine;
-    this->mColumn=orig.mColumn;
-    delete this->mCVTerms;
-    this->mCVTerms=NULL;
-    if(orig.mCVTerms)
-    {
-      this->mCVTerms=new List();
-      unsigned int i,iMax=orig.mCVTerms->getSize();
-      for(i=0;i<iMax;++i)
-      {
-        this->mCVTerms->add(static_cast<CVTerm*>(orig.mCVTerms->get(i))->clone());
-      }
-    }
   }
   
   return *this;
@@ -446,7 +405,7 @@ void Dimensions::readAttributes (const XMLAttributes& attributes,
 				                  getErrorLog()->getError(n)->getMessage();
 				getErrorLog()->remove(UnknownPackageAttribute);
 				getErrorLog()->logPackageError("layout", LayoutDimsAllowedAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				               getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
 			}
 			else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
 			{
@@ -455,7 +414,7 @@ void Dimensions::readAttributes (const XMLAttributes& attributes,
 				getErrorLog()->remove(UnknownCoreAttribute);
 				getErrorLog()->logPackageError("layout", 
                        LayoutDimsAllowedCoreAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				               getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
 			}
 		}
 	}
@@ -473,12 +432,12 @@ void Dimensions::readAttributes (const XMLAttributes& attributes,
 
 		if (mId.empty() == true)
 		{
-			logEmptyString(mId, getLevel(), getVersion(), "<Dimensions>");
+      logEmptyString(mId, getLevel(), getVersion(), "<Dimensions>");
 		}
 		else if (SyntaxChecker::isValidSBMLSId(mId) == false)
 		{
       getErrorLog()->logPackageError("layout", LayoutSIdSyntax, 
-        getPackageVersion(), sbmlLevel, sbmlVersion);
+        getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
 		}
 	}
 
@@ -498,13 +457,13 @@ void Dimensions::readAttributes (const XMLAttributes& attributes,
 				getErrorLog()->remove(XMLAttributeTypeMismatch);
 				getErrorLog()->logPackageError("layout", 
                      LayoutDimsAttributesMustBeDouble,
-				             getPackageVersion(), sbmlLevel, sbmlVersion);
+				             getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
 			}
 			else
 			{
 				std::string message = "Layout attribute 'width' is missing.";
 				getErrorLog()->logPackageError("layout", LayoutDimsAllowedAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, message);
+				               getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
 			}
 		}
 	}
@@ -525,13 +484,13 @@ void Dimensions::readAttributes (const XMLAttributes& attributes,
 				getErrorLog()->remove(XMLAttributeTypeMismatch);
 				getErrorLog()->logPackageError("layout", 
                      LayoutDimsAttributesMustBeDouble,
-				             getPackageVersion(), sbmlLevel, sbmlVersion);
+				             getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
 			}
 			else
 			{
 				std::string message = "Layout attribute 'height' is missing.";
 				getErrorLog()->logPackageError("layout", LayoutDimsAllowedAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, message);
+				               getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
 			}
 		}
 	}
@@ -553,7 +512,7 @@ void Dimensions::readAttributes (const XMLAttributes& attributes,
 				getErrorLog()->remove(XMLAttributeTypeMismatch);
 				getErrorLog()->logPackageError("layout", 
                      LayoutDimsAttributesMustBeDouble,
-				             getPackageVersion(), sbmlLevel, sbmlVersion);
+				             getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
 			}
 		}
 	}
