@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2004-2008 by European Media Laboratories Research gGmbH,
  *     Heidelberg, Germany
@@ -597,6 +602,7 @@ GeneralGlyph::createReferenceGlyph ()
   ReferenceGlyph* srg = new ReferenceGlyph(layoutns);
 
   this->mReferenceGlyphs.appendAndOwn(srg);
+  delete layoutns;
   return srg;
 }
 
@@ -771,7 +777,7 @@ GeneralGlyph::createObject (XMLInputStream& stream)
     if (mReferenceGlyphs.size() != 0)
     {
       getErrorLog()->logPackageError("layout", LayoutGGAllowedElements, 
-        getPackageVersion(), getLevel(), getVersion());
+        getPackageVersion(), getLevel(), getVersion(), "", getLine(), getColumn());
     }
 
     object = &mReferenceGlyphs;
@@ -781,7 +787,7 @@ GeneralGlyph::createObject (XMLInputStream& stream)
     if (mSubGlyphs.size() != 0)
     {
       getErrorLog()->logPackageError("layout", LayoutGGAllowedElements, 
-        getPackageVersion(), getLevel(), getVersion());
+        getPackageVersion(), getLevel(), getVersion(), "", getLine(), getColumn());
     }
 
     object = &mSubGlyphs;
@@ -791,7 +797,7 @@ GeneralGlyph::createObject (XMLInputStream& stream)
     if (getCurveExplicitlySet() == true)
     {
       getErrorLog()->logPackageError("layout", LayoutGGAllowedElements, 
-        getPackageVersion(), getLevel(), getVersion());
+        getPackageVersion(), getLevel(), getVersion(), "", getLine(), getColumn());
     }
 
     object = &mCurve;
@@ -852,13 +858,13 @@ void GeneralGlyph::readAttributes (const XMLAttributes& attributes,
         {
 				  getErrorLog()->logPackageError("layout", 
                                     LayoutLOSubGlyphAllowedAttribs,
-				            getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
         }
         else
         {
 				  getErrorLog()->logPackageError("layout", 
                                     LayoutLOAddGOAllowedAttribut,
-				            getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
         }
 			}
 			else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
@@ -870,13 +876,13 @@ void GeneralGlyph::readAttributes (const XMLAttributes& attributes,
         {
 				  getErrorLog()->logPackageError("layout", 
                                     LayoutLOSubGlyphAllowedAttribs,
-				            getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
         }
         else
         {
 				  getErrorLog()->logPackageError("layout", 
                                     LayoutLOAddGOAllowedAttribut,
-				            getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
         }
 			}
 		}
@@ -896,7 +902,7 @@ void GeneralGlyph::readAttributes (const XMLAttributes& attributes,
 				                  getErrorLog()->getError(n)->getMessage();
 				getErrorLog()->remove(UnknownPackageAttribute);
 				getErrorLog()->logPackageError("layout", LayoutGGAllowedAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				               getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
 			}
 			else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
 			{
@@ -904,7 +910,7 @@ void GeneralGlyph::readAttributes (const XMLAttributes& attributes,
 				                  getErrorLog()->getError(n)->getMessage();
 				getErrorLog()->remove(UnknownCoreAttribute);
 				getErrorLog()->logPackageError("layout", LayoutGGAllowedCoreAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				               getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
 			}
 		}
 	}
@@ -922,12 +928,12 @@ void GeneralGlyph::readAttributes (const XMLAttributes& attributes,
 
 		if (mReference.empty() == true)
 		{
-			logEmptyString(mReference, getLevel(), getVersion(), "<GeneralGlyph>");
+      logEmptyString(mReference, getLevel(), getVersion(), "<GeneralGlyph>");
 		}
 		else if (SyntaxChecker::isValidSBMLSId(mReference) == false)
 		{
 			getErrorLog()->logPackageError("layout", LayoutGGReferenceSyntax,
-				             getPackageVersion(), sbmlLevel, sbmlVersion);
+				             getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
 		}
 	}
 
@@ -1121,6 +1127,7 @@ ListOfReferenceGlyphs::createObject (XMLInputStream& stream)
     LAYOUT_CREATE_NS(layoutns,this->getSBMLNamespaces());
     object = new ReferenceGlyph(layoutns);
     appendAndOwn(object);
+    delete layoutns;
   }
 
   return object;
@@ -1214,11 +1221,8 @@ GeneralGlyph::enablePackageInternal(const std::string& pkgURI,
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
-/**
- * Creates a new GeneralGlyph and returns the pointer to it.
- */
 LIBSBML_EXTERN
 GeneralGlyph_t *
 GeneralGlyph_create (void)
@@ -1227,9 +1231,6 @@ GeneralGlyph_create (void)
 }
 
 
-/**
- * Creates a new GeneralGlyph with the given @p id
- */
 LIBSBML_EXTERN
 GeneralGlyph_t *
 GeneralGlyph_createWith (const char *sid)
@@ -1239,9 +1240,6 @@ GeneralGlyph_createWith (const char *sid)
 }
 
 
-/**
- * Creates a new GeneralGlyph referencing the give reaction.
- */
 LIBSBML_EXTERN
 GeneralGlyph_t *
 GeneralGlyph_createWithReferenceId (const char *id, const char *referenceId)
@@ -1251,9 +1249,6 @@ GeneralGlyph_createWithReferenceId (const char *id, const char *referenceId)
 }
 
 
-/**
- * Creates a new GeneralGlyph object from a template.
- */
 LIBSBML_EXTERN
 GeneralGlyph_t *
 GeneralGlyph_createFrom (const GeneralGlyph_t *temp)
@@ -1262,9 +1257,6 @@ GeneralGlyph_createFrom (const GeneralGlyph_t *temp)
 }
 
 
-/**
- * Frees the memory taken up by the attributes.
- */
 LIBSBML_EXTERN
 void
 GeneralGlyph_free (GeneralGlyph_t *rg)
@@ -1273,213 +1265,163 @@ GeneralGlyph_free (GeneralGlyph_t *rg)
 }
 
 
-/**
- * Sets the reference reaction for the reaction glyph.
- */
 LIBSBML_EXTERN
 void
 GeneralGlyph_setReferenceId (GeneralGlyph_t *rg,const char *id)
 {
-    static_cast<GeneralGlyph*>(rg)->setReferenceId( id ? id : "" );
+  if (rg == NULL) return;
+  static_cast<GeneralGlyph*>(rg)->setReferenceId( id ? id : "" );
 }
 
 
-/**
- * Gets the reference reactions id for the given reaction glyph.
- */
 LIBSBML_EXTERN
 const char *
 GeneralGlyph_getReferenceId (const GeneralGlyph_t *rg)
 {
-    return rg->isSetReferenceId() ? rg->getReferenceId().c_str() : NULL;
+  if (rg == NULL) return NULL;
+  return rg->isSetReferenceId() ? rg->getReferenceId().c_str() : NULL;
 }
 
 
-/**
- * Returns 0 if the reference reaction has not been set for this glyph and
- * 1 otherwise.
- */
 LIBSBML_EXTERN
 int
 GeneralGlyph_isSetReferenceId (const GeneralGlyph_t *rg)
 {
+  if (rg == NULL) return (int)false;
   return static_cast<int>( rg->isSetReferenceId() );
 }
 
 
-/**
- * Add a ReferenceGlyph object to the list of
- * ReferenceGlyphs.
- */
 LIBSBML_EXTERN
 void
 GeneralGlyph_addReferenceGlyph (GeneralGlyph_t         *rg,
                                         ReferenceGlyph_t *srg)
 {
+  if (rg == NULL) return;
   rg->addReferenceGlyph(srg);
 }
 
 
-/**
- * Returns the number of ReferenceGlyphs for the GeneralGlyph.
- */
 LIBSBML_EXTERN
 unsigned int
 GeneralGlyph_getNumReferenceGlyphs (const GeneralGlyph_t *rg)
 {
+  if (rg == NULL) return 0;
   return rg->getNumReferenceGlyphs();
 }
 
 
-/**
- * Returns the pointer to the ReferenceGlyphs for the given index.
- */
 LIBSBML_EXTERN
 ReferenceGlyph_t *
 GeneralGlyph_getReferenceGlyph (GeneralGlyph_t *rg,
                                         unsigned int           index)
 {
+  if (rg == NULL) return  NULL;
   return rg->getReferenceGlyph(index);
 }
 
 
-/**
- * Returns the list object that holds all reference glyphs.
- */ 
 LIBSBML_EXTERN
 ListOf_t *
 GeneralGlyph_getListOfReferenceGlyphs (GeneralGlyph_t *rg)
 {
+  if (rg == NULL) return NULL;
   return rg->getListOfReferenceGlyphs();
 }
 
 
-/**
- * Calls initDefaults from GraphicalObject.
- */ 
 LIBSBML_EXTERN
 void
 GeneralGlyph_initDefaults (GeneralGlyph_t *rg)
 {
+  if (rg == NULL) return;
   rg->initDefaults();
 }
 
 
-/**
- * Sets the curve for the reaction glyph.
- */
 LIBSBML_EXTERN
 void
 GeneralGlyph_setCurve (GeneralGlyph_t *rg, Curve_t *c)
 {
+  if (rg == NULL) return;
   rg->setCurve(c);
 }
 
 
-/**
- * Gets the Curve for the given reaction glyph.
- */
 LIBSBML_EXTERN
 Curve_t *
 GeneralGlyph_getCurve (GeneralGlyph_t *rg)
 {
+  if (rg == NULL) return NULL;
   return rg->getCurve();
 }
 
 
-/**
- * Returns true if the Curve has one or more LineSegment.
- */
 LIBSBML_EXTERN
 int
 GeneralGlyph_isSetCurve (GeneralGlyph_t *rg)
 {
+  if (rg == NULL) return (int)false;
   return static_cast<int>( rg->isSetCurve() );
 }
 
 
-/**
- * Creates a new ReferenceGlyph_t object, adds it to the end of the
- * list of reference objects and returns a pointer to the newly
- * created object.
- */
 LIBSBML_EXTERN
 ReferenceGlyph_t *
 GeneralGlyph_createReferenceGlyph (GeneralGlyph_t *rg)
 {
+  if (rg == NULL) return NULL;
   return rg->createReferenceGlyph();
 }
 
 
-/**
- * Creates a new LineSegment object, adds it to the end of the list of
- * curve segment objects of the curve and returns a reference to the newly
- * created object.
- */
 LIBSBML_EXTERN
 LineSegment_t *
 GeneralGlyph_createLineSegment (GeneralGlyph_t *rg)
 {
+  if (rg == NULL) return NULL;
   return rg->getCurve()->createLineSegment();
 }
 
 
-/**
- * Creates a new CubicBezier object, adds it to the end of the list of
- * curve segment objects of the curve and returns a reference to the newly
- * created object.
- */
 LIBSBML_EXTERN
 CubicBezier_t *
 GeneralGlyph_createCubicBezier (GeneralGlyph_t *rg)
 {
+  if (rg == NULL) return NULL;
   return rg->getCurve()->createCubicBezier();
 }
 
 
-/**
- * Remove the reference glyph with the given index.
- * A pointer to the object is returned. If no object has been removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 ReferenceGlyph_t*
 GeneralGlyph_removeReferenceGlyph(GeneralGlyph_t* rg,unsigned int index)
 {
-    return rg->removeReferenceGlyph(index);
+  if (rg == NULL) return NULL;
+  return rg->removeReferenceGlyph(index);
 }
 
-/**
- * Remove the reference glyph with the given @p id.
- * A pointer to the object is returned. If no object has been removed, NULL
- * is returned.
- */
 LIBSBML_EXTERN
 ReferenceGlyph_t*
 GeneralGlyph_removeReferenceGlyphWithId(GeneralGlyph_t* rg,const char* id)
 {
-    return rg->removeReferenceGlyph(id);
+  if (rg == NULL) return NULL;
+  return rg->removeReferenceGlyph(id);
 }
 
-/**
- * Returns the index of the reference glyph with the given @p id.
- * If the reaction glyph does not contain a reference glyph with this
- * id, UINT_MAX from limits.h is returned.
- */
 LIBSBML_EXTERN
 unsigned int
 GeneralGlyph_getIndexForReferenceGlyph(GeneralGlyph_t* rg,const char* id)
 {
-    return rg->getIndexForReferenceGlyph(id);
+  if (rg == NULL) return 0;
+  return rg->getIndexForReferenceGlyph(id);
 }
 
-/**
- * @return a (deep) copy of this GeneralGlyph.
- */
 LIBSBML_EXTERN
 GeneralGlyph_t *
 GeneralGlyph_clone (const GeneralGlyph_t *m)
 {
+  if (m == NULL) return NULL;
   return static_cast<GeneralGlyph*>( m->clone() );
 }
 
