@@ -94,69 +94,21 @@ Point::Point(const Point& orig):SBase(orig)
     this->mXOffset=orig.mXOffset;
     this->mYOffset=orig.mYOffset;
     this->mZOffset=orig.mZOffset;
-    this->mElementName=orig.mElementName;
-
     this->mZOffsetExplicitlySet=orig.mZOffsetExplicitlySet;
-    // attributes of SBase
-    //this->mId=orig.mId;
-    //this->mName=orig.mName;
-    this->mMetaId=orig.mMetaId;
-    if(orig.mNotes) this->mNotes=new XMLNode(*const_cast<Point&>(orig).getNotes());
-    if(orig.mAnnotation) this->mAnnotation=new XMLNode(*const_cast<Point&>(orig).mAnnotation);
-    this->mSBML=orig.mSBML;
-    this->mSBOTerm=orig.mSBOTerm;
-    this->mLine=orig.mLine;
-    this->mColumn=orig.mColumn;
-
-    if(orig.mCVTerms)
-    {
-      this->mCVTerms=new List();
-      unsigned int i,iMax=orig.mCVTerms->getSize();
-      for(i=0;i<iMax;++i)
-      {
-        this->mCVTerms->add(static_cast<CVTerm*>(orig.mCVTerms->get(i))->clone());
-      }
-    }
+    this->mElementName=orig.mElementName;
 }
 
 Point& Point::operator=(const Point& orig)
 {
   if(&orig!=this)
   {
+    SBase::operator=(orig);
+    this->mId=orig.mId;
     this->mXOffset=orig.mXOffset;
     this->mYOffset=orig.mYOffset;
     this->mZOffset=orig.mZOffset;
-    this->mElementName=orig.mElementName;
-
     this->mZOffsetExplicitlySet=orig.mZOffsetExplicitlySet;
-    this->mMetaId=orig.mMetaId;
-    delete this->mNotes;
-    this->mNotes=NULL;
-    if(orig.mNotes)
-    {
-        this->mNotes=new XMLNode(*const_cast<Point&>(orig).getNotes());
-    }
-    delete this->mAnnotation;
-    this->mAnnotation=NULL;
-    if(orig.mAnnotation)
-    {
-        this->mAnnotation=new XMLNode(*const_cast<Point&>(orig).mAnnotation);
-    }
-    this->mSBML=orig.mSBML;
-    this->mSBOTerm=orig.mSBOTerm;
-    this->mLine=orig.mLine;
-    this->mColumn=orig.mColumn;
-    delete this->mCVTerms;
-    this->mCVTerms=NULL;
-    if(orig.mCVTerms)
-    {
-      this->mCVTerms=new List();
-      unsigned int i,iMax=orig.mCVTerms->getSize();
-      for(i=0;i<iMax;++i)
-      {
-        this->mCVTerms->add(static_cast<CVTerm*>(orig.mCVTerms->get(i))->clone());
-      }
-    }
+    this->mElementName=orig.mElementName;
   }
   
   return *this;
@@ -522,7 +474,7 @@ void Point::readAttributes (const XMLAttributes& attributes,
 				                  getErrorLog()->getError(n)->getMessage();
 				getErrorLog()->remove(UnknownPackageAttribute);
 				getErrorLog()->logPackageError("layout", LayoutPointAllowedAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				               getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
 			}
 			else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
 			{
@@ -531,7 +483,7 @@ void Point::readAttributes (const XMLAttributes& attributes,
 				getErrorLog()->remove(UnknownCoreAttribute);
 				getErrorLog()->logPackageError("layout", 
                        LayoutPointAllowedCoreAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				               getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
 			}
 		}
 	}
@@ -549,12 +501,12 @@ void Point::readAttributes (const XMLAttributes& attributes,
 
 		if (mId.empty() == true)
 		{
-			logEmptyString(mId, getLevel(), getVersion(), "<Point>");
+      logEmptyString(mId, getLevel(), getVersion(), "<Point>");
 		}
 		else if (SyntaxChecker::isValidSBMLSId(mId) == false)
 		{
       getErrorLog()->logPackageError("layout", LayoutSIdSyntax, 
-        getPackageVersion(), sbmlLevel, sbmlVersion);
+        getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
 		}
 	}
 
@@ -574,13 +526,13 @@ void Point::readAttributes (const XMLAttributes& attributes,
 				getErrorLog()->remove(XMLAttributeTypeMismatch);
 				getErrorLog()->logPackageError("layout", 
                      LayoutPointAttributesMustBeDouble,
-				             getPackageVersion(), sbmlLevel, sbmlVersion);
+				             getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
 			}
 			else
 			{
 				std::string message = "Layout attribute 'x' is missing.";
 				getErrorLog()->logPackageError("layout", LayoutPointAllowedAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, message);
+				               getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
 			}
 		}
 	}
@@ -601,13 +553,13 @@ void Point::readAttributes (const XMLAttributes& attributes,
 				getErrorLog()->remove(XMLAttributeTypeMismatch);
 				getErrorLog()->logPackageError("layout", 
                      LayoutPointAttributesMustBeDouble,
-				             getPackageVersion(), sbmlLevel, sbmlVersion);
+				             getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
 			}
 			else
 			{
 				std::string message = "Layout attribute 'y' is missing.";
 				getErrorLog()->logPackageError("layout", LayoutPointAllowedAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, message);
+				               getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
 			}
 		}
 	}
@@ -629,7 +581,7 @@ void Point::readAttributes (const XMLAttributes& attributes,
 				getErrorLog()->remove(XMLAttributeTypeMismatch);
 				getErrorLog()->logPackageError("layout", 
                      LayoutPointAttributesMustBeDouble,
-				             getPackageVersion(), sbmlLevel, sbmlVersion);
+				             getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
 			}
 		}
 	}
