@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2004-2008 by European Media Laboratories Research gGmbH,
  *     Heidelberg, Germany
@@ -22,8 +27,7 @@
  * ------------------------------------------------------------------------ -->
  *
  * @class ReactionGlyph
- * @sbmlbrief{layout} The %ReactionGlyph is used to represent Reaction
- * elements in the layout.
+ * @sbmlbrief{layout} A glyph for an SBML reaction.
  *
  * Analogous to how a Reaction object has to at least have one reactant or
  * product, the ReactionGlyph has to at least have one SpeciesReferenceGlyph
@@ -63,8 +67,7 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 
 /**
  * @class ListOfSpeciesReferenceGlyphs
- * @sbmlbrief{layout} Implementation of the %ListOfSpeciesReferenceGlyphs
- * construct from the &ldquo;layout&rdquo; package.
+ * @sbmlbrief{layout} A list of SpeciesReferenceGlyph objects.
  * 
  * The ListOfSpeciesReferenceGlyphs is a container for the SpeciesReferenceGlyphs elements of a ReactionGlyph.
  * 
@@ -103,16 +106,19 @@ public:
    * @copydetails doc_what_are_typecodes
    *
    * @return the SBML type code for objects contained in this list:
-   * @link SBMLTypeCode_t#SBML_LAYOUT_SPECIESREFERENCEGLYPH SBML_LAYOUT_SPECIESREFERENCEGLYPH@endlink (default).
+   * @sbmlconstant{SBML_LAYOUT_SPECIESREFERENCEGLYPH, SBMLTypeCode_t} (default).
    *
    * @see getElementName()
    * @see getPackageName()
    */
   virtual int getItemTypeCode () const;
 
+
   /**
    * Returns the XML element name of
    * this SBML object.
+   *
+   * @return the string of the name of this element
    */
   virtual const std::string& getElementName () const;
 
@@ -368,17 +374,9 @@ public:
    */
   virtual List* getAllElements(ElementFilter* filter=NULL);
 
+
   /**
-   * Renames all the @c SIdRef attributes on this element, including any
-   * found in MathML content (if such exists).
-   *
-   * This method works by looking at all attributes and (if appropriate)
-   * mathematical formulas, comparing the identifiers to the value of @p
-   * oldid.  If any matches are found, the matching identifiers are replaced
-   * with @p newid.  The method does @em not descend into child elements.
-   *
-   * @param oldid the old identifier
-   * @param newid the new identifier
+   * @copydoc doc_renamesidref_common
    */
   virtual void renameSIdRefs(const std::string& oldid, const std::string& newid);
 
@@ -451,7 +449,7 @@ public:
   /**
    * Returns the index of the species reference glyph with the given @p id.
    * If the reaction glyph does not contain a species reference glyph with this
-   * id, @if cpp numeric_limits<unsigned int>::max() @endif@if notcpp the
+   * id, @if cpp numeric_limits<unsigned int>::max() @else the
    * value of the maximum long integer@endif@~ is returned as an indicator.
    */
   
@@ -473,12 +471,16 @@ public:
   virtual void writeElements (XMLOutputStream& stream) const;
   /** @endcond */
 
+
   /**
    * Returns the XML element name of
    * this SBML object.
+   *
+   * @return the string of the name of this element
    */
   virtual const std::string& getElementName () const ;
 
+
   /**
    * Creates and returns a deep copy of this ReactionGlyph object.
    * 
@@ -493,7 +495,7 @@ public:
    * @copydetails doc_what_are_typecodes
    *
    * @return the SBML type code for this object:
-   * @link SBMLLayoutTypeCode_t#SBML_LAYOUT_REACTIONGLYPH SBML_LAYOUT_REACTIONGLYPH@endlink
+   * @sbmlconstant{SBML_LAYOUT_REACTIONGLYPH, SBMLLayoutTypeCode_t}
    *
    * @copydetails doc_warning_typecodes_not_unique
    *
@@ -622,90 +624,140 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 BEGIN_C_DECLS
 
 
-/*
- * Creates a new ReactionGlyph and returns the pointer to it.
+/**
+ * Creates a new ReactionGlyph_t and returns the pointer to it.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 ReactionGlyph_t *
 ReactionGlyph_create (void);
 
 
-/*
- * Creates a new ReactionGlyph object from a template.
+/**
+ * Creates a new ReactionGlyph_t structure from a template.
+ *
+ * @param temp The ReactionGlyph_t structure to copy.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 ReactionGlyph_t *
 ReactionGlyph_createFrom (const ReactionGlyph_t *temp);
 
-/*
+/**
  * Frees the memory taken up by the attributes.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 void
 ReactionGlyph_clear (ReactionGlyph_t *rg);
 
 
-/*
- * Creates a new ReactionGlyph with the given @p sid
+/**
+ * Creates a new ReactionGlyph_t with the given @p sid
+ *
+ * @param sid The string to use as the ID of the ReactionGlyph_t
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 ReactionGlyph_t *
 ReactionGlyph_createWith (const char *sid);
 
-/*
- * Creates a new ReactionGlyph referencing the give reaction.
+/**
+ * Creates a new ReactionGlyph_t referencing the given reaction.
+ *
+ * @param sid The string to use as the ID of the ReactionGlyph_t
+ * @param reactionId The string to use as the reaction ID.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 ReactionGlyph_t *
-ReactionGlyph_createWithReactionId (const char *id,const char *reactionId);
+ReactionGlyph_createWithReactionId (const char *sid, const char *reactionId);
 
-/*
+/**
  * Frees the memory taken by the given reaction glyph.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 void
 ReactionGlyph_free (ReactionGlyph_t *rg);
 
-/*
+/**
  * Sets the reference reaction for the reaction glyph.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ * @param id The string to use as the reaction ID.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 void
 ReactionGlyph_setReactionId (ReactionGlyph_t *rg,const char *id);
 
-/*
+/**
  * Gets the reference reactions id for the given reaction glyph.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 const char *
 ReactionGlyph_getReactionId (const ReactionGlyph_t *rg);
 
-/*
+/**
  * Returns 0 if the reference reaction has not been set for this glyph and
  * 1 otherwise.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 int
 ReactionGlyph_isSetReactionId (const ReactionGlyph_t *rg);
 
-/*
- * Add a SpeciesReferenceGlyph object to the list of
- * SpeciesReferenceGlyphs.
+/**
+ * Add a SpeciesReferenceGlyph_t structure to the list of
+ * SpeciesReferenceGlyph_t's.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ * @param srg The SpeciesReferenceGlyph_t structure to add.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 void
 ReactionGlyph_addSpeciesReferenceGlyph (ReactionGlyph_t         *rg,
                                         SpeciesReferenceGlyph_t *srg);
 
-/*
- * Returns the number of SpeciesReferenceGlyphs for the ReactionGlyph.
+/**
+ * Returns the number of SpeciesReferenceGlyphs for the ReactionGlyph_t.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 unsigned int
 ReactionGlyph_getNumSpeciesReferenceGlyphs (const ReactionGlyph_t *rg);
 
-/*
- * Returns the pointer to the SpeciesReferenceGlyphs for the given index.
+/**
+ * Returns the pointer to the SpeciesReferenceGlyph_t's for the given index.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ * @param index The index of the SpeciesReferenceGlyph_t to return.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t *
@@ -713,119 +765,180 @@ ReactionGlyph_getSpeciesReferenceGlyph (ReactionGlyph_t *rg,
                                         unsigned int index);
 
 
-/*
- * Returns the list object that holds all species reference glyphs.
+/**
+ * Returns the list structure that holds all species reference glyphs.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ *
+ * @memberof ReactionGlyph_t
  */ 
 LIBSBML_EXTERN
 ListOf_t *
 ReactionGlyph_getListOfSpeciesReferenceGlyphs (ReactionGlyph_t *rg);
 
-/*
+/**
  * Removes the species reference glyph with the given index.  If the index
  * is invalid, nothing is removed.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ * @param index The index of the SpeciesReferenceGlyph_t to remove.
+ *
+ * @memberof ReactionGlyph_t
  */ 
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t *
 ReactionGlyph_removeSpeciesReferenceGlyph (ReactionGlyph_t *rg,
                                            unsigned int index);
 
-/*
+/**
  * Calls initDefaults from GraphicalObject.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ *
+ * @memberof ReactionGlyph_t
  */ 
 LIBSBML_EXTERN
 void
 ReactionGlyph_initDefaults (ReactionGlyph_t *rg);
 
-/*
+/**
  * Sets the curve for the reaction glyph.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ * @param c The Curve_t to set for the SpeciesReferenceGlyph_t
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 void
 ReactionGlyph_setCurve (ReactionGlyph_t *rg, Curve_t *c);
 
-/*
- * Gets the Curve for the given reaction glyph.
+/**
+ * Gets the Curve_t for the given reaction glyph.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 Curve_t *
 ReactionGlyph_getCurve (ReactionGlyph_t *rg);
 
-/*
- * Returns true if the Curve has one or more LineSegment.
+/**
+ * Returns true if the Curve_t has one or more LineSegment.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 int
 ReactionGlyph_isSetCurve (ReactionGlyph_t *rg);
 
-/*
- * Creates a new SpeciesReferenceGlyph_t object, adds it to the end of the
- * list of species reference objects and returns a pointer to the newly
- * created object.
+/**
+ * Creates a new SpeciesReferenceGlyph_t structure, adds it to the end of the
+ * list of species reference glyphs and returns a pointer to the newly
+ * created structure.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t *
 ReactionGlyph_createSpeciesReferenceGlyph (ReactionGlyph_t *rg);
 
-/*
- * Creates a new SpeciesReferenceGlyph_t object, adds it to the end of the
- * list of species reference objects and returns a pointer to the newly
- * created object.
+/**
+ * Creates a new SpeciesReferenceGlyph_t structure, adds it to the end of the
+ * list of species reference glyphs and returns a pointer to the newly
+ * created structure.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t *
 ReactionGlyph_createSpeciesReferenceGlyph (ReactionGlyph_t *rg);
 
-/*
- * Creates a new LineSegment object, adds it to the end of the list of
- * curve segments objects and returns a pointer to the newly created
- * object.
+/**
+ * Creates a new LineSegment_t structure, adds it to the end of the list of
+ * curve segments and returns a pointer to the newly created
+ * structure.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 LineSegment_t *
 ReactionGlyph_createLineSegment (ReactionGlyph_t *rg);
 
-/*
- * Creates a new CubicBezier object, adds it to the end of the list of
- * curve segments objects and returns a pointer to the newly created
- * object.
+/**
+ * Creates a new CubicBezier_t structure, adds it to the end of the list of
+ * curve segments and returns a pointer to the newly created
+ * structure.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 CubicBezier_t *
 ReactionGlyph_createCubicBezier (ReactionGlyph_t *rg);
 
-/*
+/**
  * Remove the species reference glyph with the given index.
- * A pointer to the object is returned. If no object has been removed, NULL
+ * A pointer to the structure is returned. If no structure has been removed, NULL
  * is returned.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ * @param index The index of the SpeciesReferenceGlyph_t to remove.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t*
 ReactionGlyph_removeSpeciesReferenceGlyph(ReactionGlyph_t* rg,unsigned int index);
 
-/*
+/**
  * Remove the species reference glyph with the given @p id.
- * A pointer to the object is returned. If no object has been removed, NULL
+ * A pointer to the structure is returned. If no structure has been removed, NULL
  * is returned.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ * @param id The id of the SpeciesReferenceGlyph_t to remove.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t*
 ReactionGlyph_removeSpeciesReferenceGlyphWithId(ReactionGlyph_t* rg,const char* id);
 
-/*
+/**
  * Returns the index of the species reference glyph with the given @p id.
  * If the reaction glyph does not contain a species reference glyph with this
  * id, UINT_MAX from limits.h is returned.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ * @param id The idof the SpeciesReferenceGlyph_t to find.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 unsigned int
 ReactionGlyph_getIndexForSpeciesReferenceGlyph(ReactionGlyph_t* rg,const char* id);
 
-/*
- * @return a (deep) copy of this ReactionGlyph.
+/**
+ * @return a (deep) copy of this ReactionGlyph_t.
+ *
+ * @param rg The ReactionGlyph_t structure.
+ *
+ * @memberof ReactionGlyph_t
  */
 LIBSBML_EXTERN
 ReactionGlyph_t *
-ReactionGlyph_clone (const ReactionGlyph_t *m);
+ReactionGlyph_clone (const ReactionGlyph_t *rg);
 
 
 END_C_DECLS
