@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2004-2008 by European Media Laboratories Research gGmbH,
  *     Heidelberg, Germany
@@ -40,7 +45,7 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 #ifdef __cplusplus
 
 /** @cond doxygenLibsbmlInternal */
-const std::string SpeciesReferenceGlyph::SPECIES_REFERENCE_ROLE_STRING[]={
+static const std::string SPECIES_REFERENCE_ROLE_STRING[]={
     "undefined" 
    ,"substrate"
    ,"product"
@@ -129,7 +134,7 @@ SpeciesReferenceGlyph::SpeciesReferenceGlyph(LayoutPkgNamespaces* layoutns)
  * Creates a new SpeciesReferenceGlyph.  The id is given as the first
  * argument, the id of the associated species reference is given as the
  * second argument.  The third argument is the id of the associated species
- * glpyh and the fourth argument is the role.
+ * glyph and the fourth argument is the role.
  */ 
 SpeciesReferenceGlyph::SpeciesReferenceGlyph
 (
@@ -310,7 +315,7 @@ SpeciesReferenceGlyph::getRole() const
  * Returns a string representation for the role
  */
 const std::string& SpeciesReferenceGlyph::getRoleString() const{
-    return SpeciesReferenceGlyph::SPECIES_REFERENCE_ROLE_STRING[this->mRole];
+    return SPECIES_REFERENCE_ROLE_STRING[this->mRole];
 }
 
 /*
@@ -395,7 +400,7 @@ SpeciesReferenceGlyph::getCurveExplicitlySet() const
 
 
 /*
- * Returns true if the id of the associated species glpyh is not the empty
+ * Returns true if the id of the associated species glyph is not the empty
  * string.
  */ 
 bool
@@ -494,7 +499,7 @@ SpeciesReferenceGlyph::createObject (XMLInputStream& stream)
     if (getCurveExplicitlySet() == true)
     {
       getErrorLog()->logPackageError("layout", LayoutSRGAllowedElements, 
-        getPackageVersion(), getLevel(), getVersion());
+        getPackageVersion(), getLevel(), getVersion(), "", getLine(), getColumn());
     }
 
     object = &mCurve;
@@ -558,13 +563,13 @@ void SpeciesReferenceGlyph::readAttributes (const XMLAttributes& attributes,
         {
 				  getErrorLog()->logPackageError("layout", 
                                     LayoutLOSubGlyphAllowedAttribs,
-				            getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
         }
         else
         {
 				  getErrorLog()->logPackageError("layout", 
                                     LayoutLOSpeciesRefGlyphAllowedAttribs,
-				            getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
         }
 			}
 			else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
@@ -576,13 +581,13 @@ void SpeciesReferenceGlyph::readAttributes (const XMLAttributes& attributes,
         {
 				  getErrorLog()->logPackageError("layout", 
                                     LayoutLOSubGlyphAllowedAttribs,
-				            getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
         }
         else
         {
 				  getErrorLog()->logPackageError("layout", 
                                     LayoutLOSpeciesRefGlyphAllowedAttribs,
-				            getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
         }
 			}
 		}
@@ -602,7 +607,7 @@ void SpeciesReferenceGlyph::readAttributes (const XMLAttributes& attributes,
 				                  getErrorLog()->getError(n)->getMessage();
 				getErrorLog()->remove(UnknownPackageAttribute);
 				getErrorLog()->logPackageError("layout", LayoutSRGAllowedAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				               getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
 			}
 			else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
 			{
@@ -610,7 +615,7 @@ void SpeciesReferenceGlyph::readAttributes (const XMLAttributes& attributes,
 				                  getErrorLog()->getError(n)->getMessage();
 				getErrorLog()->remove(UnknownCoreAttribute);
 				getErrorLog()->logPackageError("layout", LayoutSRGAllowedCoreAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, details);
+				               getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
 			}
 		}
 	}
@@ -631,19 +636,19 @@ void SpeciesReferenceGlyph::readAttributes (const XMLAttributes& attributes,
 		  if (mSpeciesGlyph.empty() == true)
 		  {
 			  logEmptyString(mSpeciesGlyph, getLevel(), getVersion(), 
-                                     "<SpeciesReferenceGlyph>");
+          "<SpeciesReferenceGlyph>");
 		  }
 		  else if (SyntaxChecker::isValidSBMLSId(mSpeciesGlyph) == false)
 		  {
         getErrorLog()->logPackageError("layout", LayoutSRGSpeciesGlyphSyntax, 
-            getPackageVersion(), sbmlLevel, sbmlVersion);
+          getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
 		  }
 	  }
 	  else
 	  {
 		  std::string message = "Layout attribute 'speciesGlyph' is missing.";
 		  getErrorLog()->logPackageError("layout", LayoutSRGAllowedAttributes,
-		                 getPackageVersion(), sbmlLevel, sbmlVersion, message);
+		                 getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
 	  }
   }
 
@@ -659,13 +664,13 @@ void SpeciesReferenceGlyph::readAttributes (const XMLAttributes& attributes,
 		if (mSpeciesReference.empty() == true)
 		{
 			logEmptyString(mSpeciesReference, getLevel(), getVersion(), 
-                                        "<SpeciesReferenceGlyph>");
+        "<SpeciesReferenceGlyph>");
 		}
 		else if (SyntaxChecker::isValidSBMLSId(mSpeciesReference) == false)
 		{
 
       getErrorLog()->logPackageError("layout", LayoutSRGSpeciesReferenceSyntax, 
-          getPackageVersion(), sbmlLevel, sbmlVersion);
+          getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
 		}
 	}
 
@@ -681,7 +686,7 @@ void SpeciesReferenceGlyph::readAttributes (const XMLAttributes& attributes,
 
 		if (role.empty() == true && getErrorLog() != NULL)
 		{
-			logEmptyString(role, getLevel(), getVersion(), "<SpeciesReferenceGlyph>");
+      logEmptyString(role, getLevel(), getVersion(), "<SpeciesReferenceGlyph>");
 		}
     else
     {
@@ -690,7 +695,7 @@ void SpeciesReferenceGlyph::readAttributes (const XMLAttributes& attributes,
       if (this->getRole() == SPECIES_ROLE_UNDEFINED && getErrorLog() != NULL)
       {
         getErrorLog()->logPackageError("layout", LayoutSRGRoleSyntax, 
-            getPackageVersion(), sbmlLevel, sbmlVersion);
+            getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
       }
     }
 	}
@@ -836,10 +841,8 @@ SpeciesReferenceGlyph::enablePackageInternal(const std::string& pkgURI,
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
-/**
- * Creates a new SpeciesReferenceGlyph object and returns a pointer to it.
- */
+/** @cond doxygenIgnored */
+
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t *
 SpeciesReferenceGlyph_create(void)
@@ -848,9 +851,6 @@ SpeciesReferenceGlyph_create(void)
 }
 
 
-/**
- * Creates a new SpeciesReferenceGlyph from a template.
- */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t *
 SpeciesReferenceGlyph_createFrom (const SpeciesReferenceGlyph_t *temp)
@@ -859,26 +859,19 @@ SpeciesReferenceGlyph_createFrom (const SpeciesReferenceGlyph_t *temp)
 }
 
 
-/**
- * Creates a new SpeciesReferenceGlyph object with the given @p id and returns
- * a pointer to it.
- */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t *
 SpeciesReferenceGlyph_createWith (const char *sid,
-                                  const char *speciesReferenceId,
                                   const char *speciesGlyphId,
+                                  const char *speciesReferenceId,
                                   SpeciesReferenceRole_t role)
 {
   LayoutPkgNamespaces layoutns;
   return new(std::nothrow)
-    SpeciesReferenceGlyph(&layoutns, sid ? sid : "", speciesReferenceId ? speciesReferenceId : "", speciesGlyphId ? speciesGlyphId : "", role);
+    SpeciesReferenceGlyph(&layoutns, sid ? sid : "", speciesGlyphId ? speciesGlyphId : "", speciesReferenceId ? speciesReferenceId : "", role);
 }
 
 
-/**
- * Frees the memory for the SpeciesReferenceGlyph
- */
 LIBSBML_EXTERN
 void
 SpeciesReferenceGlyph_free(SpeciesReferenceGlyph_t *srg)
@@ -887,242 +880,191 @@ SpeciesReferenceGlyph_free(SpeciesReferenceGlyph_t *srg)
 }
 
 
-/**
- * Sets the reference species for the species glyph.
- */
 LIBSBML_EXTERN
 void
 SpeciesReferenceGlyph_setSpeciesReferenceId (SpeciesReferenceGlyph_t *srg,
                                              const char *id)
 {
-    srg->setSpeciesReferenceId( id ? id : "" );
+  if (srg == NULL) return;
+  srg->setSpeciesReferenceId( id ? id : "" );
 }
 
 
-/**
- * Gets the reference species id for the given species glyph.
- */
 LIBSBML_EXTERN
 const char *
 SpeciesReferenceGlyph_getSpeciesReferenceId (const SpeciesReferenceGlyph_t *srg)
 {
-    return srg->isSetSpeciesReferenceId() ? srg->getSpeciesReferenceId().c_str() : NULL;
+  if (srg == NULL) return NULL;
+  return srg->isSetSpeciesReferenceId() ? srg->getSpeciesReferenceId().c_str() : NULL;
 }
 
 
-/**
- * Returns 0 if the reference species reference has not been set for this
- * glyph and 1 otherwise.
- */
 LIBSBML_EXTERN
 int
 SpeciesReferenceGlyph_isSetSpeciesReferenceId
   (const SpeciesReferenceGlyph_t *srg)
 {
-    return (int)srg->isSetSpeciesReferenceId();
+  if (srg == NULL) return (int)false;
+  return (int)srg->isSetSpeciesReferenceId();
 }
 
 
-/**
- * Sets the species glyph reference for the species glyph.
- */
 LIBSBML_EXTERN
 void
 SpeciesReferenceGlyph_setSpeciesGlyphId (SpeciesReferenceGlyph_t *srg,
                                          const char *id)
 {
-    srg->setSpeciesGlyphId( id ? id : "" );
+  if (srg == NULL) return;
+  srg->setSpeciesGlyphId( id ? id : "" );
 }
 
 
-/**
- * Gets the reference speciess id for the given species glyph.
- */
 LIBSBML_EXTERN
 const char *
 SpeciesReferenceGlyph_getSpeciesGlyphId (const SpeciesReferenceGlyph_t *srg)
 {
-    return srg->isSetSpeciesGlyphId() ? srg->getSpeciesGlyphId().c_str() : NULL;
+  if (srg == NULL) return NULL;
+  return srg->isSetSpeciesGlyphId() ? srg->getSpeciesGlyphId().c_str() : NULL;
 }
 
 
-/**
- * Returns 0 if  the reference species reference has not  been set for this
- * glyph and 1 otherwise.
- */
 LIBSBML_EXTERN
 int
 SpeciesReferenceGlyph_isSetSpeciesGlyphId (const SpeciesReferenceGlyph_t *srg)
 {
+  if (srg == NULL) return (int)false;
   return static_cast<int>( srg->isSetSpeciesGlyphId() );
 }
 
 
-/**
- * Sets the curve for the species reference glyph.
- */
 LIBSBML_EXTERN
 void
 SpeciesReferenceGlyph_setCurve(SpeciesReferenceGlyph_t *srg, Curve_t *c)
 {
+  if (srg == NULL) return;
   srg->setCurve(c);
 }
 
 
-/**
- * Gets the Curve for the given species reference glyph.
- */
 LIBSBML_EXTERN
 Curve_t *
 SpeciesReferenceGlyph_getCurve (SpeciesReferenceGlyph_t *srg)
 {
+  if (srg == NULL) return NULL;
   return srg->getCurve();
 }
 
 
-/**
- * Returns true if the Curve has one or more LineSegment.
- */
 LIBSBML_EXTERN
 int
 SpeciesReferenceGlyph_isSetCurve (SpeciesReferenceGlyph_t *srg)
 {
+  if (srg == NULL) return (int)false;
   return static_cast<int>( srg->isSetCurve() );
 }
 
 
-/**
- * Sets the role of the species reference glyph based on the string.  The
- * string can be one of UNDEFINED, SUBSTRATE, PRODUCT, SIDESUBSTRATE,
- * SIDEPRODUCT, MODIFIER, INHIBITOR or ACTIVATOR.  If it is none of those,
- * the role is set to SPECIES_ROLE_UNDEFINED.
- */
 LIBSBML_EXTERN
 void
 SpeciesReferenceGlyph_setRole (SpeciesReferenceGlyph_t *srg,
                                const char *r)
 {
+  if (srg == NULL) return;
   srg->setRole(r);
 }
 
 
-/**
- * Returns the role of the species reference.
- */ 
 LIBSBML_EXTERN
 SpeciesReferenceRole_t
 SpeciesReferenceGlyph_getRole (const SpeciesReferenceGlyph_t *srg)
 {
+  if (srg == NULL) return SPECIES_ROLE_UNDEFINED;
   return srg->getRole();
 }
 
-/**
- * Returns a string representation of the role of the species reference.
- */ 
 LIBSBML_EXTERN
 const char*
-SpeciesReferenceGlyph_getRoleString(const SpeciesReferenceGlyph_t* srg){
-    return srg->getRoleString().empty() ? NULL : srg->getRoleString().c_str();
+SpeciesReferenceGlyph_getRoleString(const SpeciesReferenceGlyph_t* srg)
+{
+  if (srg == NULL) return NULL;
+  return srg->getRoleString().empty() ? NULL : srg->getRoleString().c_str();
 }
 
 
 
-/**
- * Returns true if the role is not SPECIES_ROLE_UNDEFINED.
- */ 
 LIBSBML_EXTERN
 int
 SpeciesReferenceGlyph_isSetRole (const SpeciesReferenceGlyph_t *srg)
 {
+  if (srg == NULL) return (int)false;
   return static_cast<int>( srg->isSetRole() );
 }
 
 
-/**
- * Calls initDefaults on GraphicalObject and sets role to
- * SPECIES_ROLE_UNDEFINED.
- */ 
 LIBSBML_EXTERN
 void
 SpeciesReferenceGlyph_initDefaults (SpeciesReferenceGlyph_t *srg)
 {
+  if (srg == NULL) return;
   srg->initDefaults();
 }
 
 
-/**
- * Creates a new LineSegment object, adds it to the end of the list of
- * curve segment objects of the curve and returns a reference to the newly
- * created object.
- */
 LIBSBML_EXTERN
 LineSegment_t *
 SpeciesReferenceGlyph_createLineSegment (SpeciesReferenceGlyph_t *srg)
 {
+  if (srg == NULL || srg->getCurve() == NULL) return NULL;
   return srg->getCurve()->createLineSegment();
 }  
 
 
-/**
- * Creates a new CubicBezier object, adds it to the end of the list of
- * curve segment objects of the curve and returns a reference to the newly
- * created object.
- */
 LIBSBML_EXTERN
 CubicBezier_t *
 SpeciesReferenceGlyph_createCubicBezier (SpeciesReferenceGlyph_t *srg)
 {
+  if (srg == NULL || srg->getCurve() == NULL) return NULL;
   return srg->getCurve()->createCubicBezier();
 }
 
 
-/**
- * @return a (deep) copy of this SpeciesReferenceGlyph.
- */
 LIBSBML_EXTERN
 SpeciesReferenceGlyph_t *
 SpeciesReferenceGlyph_clone (const SpeciesReferenceGlyph_t *m)
 {
+  if (m == NULL) return NULL;
   return static_cast<SpeciesReferenceGlyph*>( m->clone() );
 }
 
-/**
- * Returns non-zero if the id is set
- */
 LIBSBML_EXTERN
 int
 SpeciesReferenceGlyph_isSetId (const SpeciesReferenceGlyph_t *srg)
 {
+  if (srg == NULL) return (int)false;
   return static_cast <int> (srg->isSetId());
 }
 
-/**
- * Returns the id
- */
 LIBSBML_EXTERN
 const char *
 SpeciesReferenceGlyph_getId (const SpeciesReferenceGlyph_t *srg)
 {
+  if (srg == NULL) return NULL;
   return srg->isSetId() ? srg->getId().c_str() : NULL;
 }
 
-/**
- * Sets the id
- */
 LIBSBML_EXTERN
 int
 SpeciesReferenceGlyph_setId (SpeciesReferenceGlyph_t *srg, const char *sid)
 {
+  if (srg == NULL) return (int)false;
   return (sid == NULL) ? srg->setId("") : srg->setId(sid);
 }
 
-/**
- * Unsets the id
- */
 LIBSBML_EXTERN
 void
 SpeciesReferenceGlyph_unsetId (SpeciesReferenceGlyph_t *srg)
 {
+  if (srg == NULL) return;
   srg->unsetId();
 }
 
