@@ -37,7 +37,6 @@
 #include <sbml/packages/multi/extension/MultiModelPlugin.h>
 #include <sbml/packages/multi/extension/MultiCompartmentPlugin.h>
 #include <sbml/packages/multi/extension/MultiSpeciesPlugin.h>
-#include <sbml/packages/multi/extension/MultiReactionPlugin.h>
 #include <sbml/packages/multi/extension/MultiSimpleSpeciesReferencePlugin.h>
 #include <sbml/packages/multi/extension/MultiSpeciesReferencePlugin.h>
 #include <sbml/packages/multi/extension/MultiSBMLDocumentPlugin.h>
@@ -139,6 +138,8 @@ const char * SBML_MULTI_TYPECODE_STRINGS[] =
   , "SpeciesFeature"
   , "SpeciesTypeComponentMapInProduct"
   , "MultiSpeciesType"
+  , "BindingSiteSpeciesType"
+  , "IntraSpeciesReaction"
 };
 
 
@@ -303,7 +304,7 @@ const char*
 MultiExtension::getStringFromTypeCode(int typeCode) const
 {
   int min = SBML_MULTI_POSSIBLE_SPECIES_FEATURE_VALUE;
-  int max = SBML_MULTI_SPECIES_TYPE;
+  int max = SBML_MULTI_INTRA_SPECIES_REACTION;
 
   if ( typeCode < min || typeCode > max)
   {
@@ -354,7 +355,6 @@ MultiExtension::init()
   SBaseExtensionPoint modelExtPoint("core", SBML_MODEL);
   SBaseExtensionPoint compartmentExtPoint("core", SBML_COMPARTMENT);
   SBaseExtensionPoint speciesExtPoint("core", SBML_SPECIES);
-  SBaseExtensionPoint reactionExtPoint("core", SBML_REACTION);
   SBaseExtensionPoint simplespeciesreferenceExtPoint("core", SBML_MODIFIER_SPECIES_REFERENCE);
   SBaseExtensionPoint speciesreferenceExtPoint("core", SBML_SPECIES_REFERENCE);
 
@@ -362,7 +362,6 @@ MultiExtension::init()
   SBasePluginCreator<MultiModelPlugin, MultiExtension> modelPluginCreator(modelExtPoint, packageURIs);
   SBasePluginCreator<MultiCompartmentPlugin, MultiExtension> compartmentPluginCreator(compartmentExtPoint, packageURIs);
   SBasePluginCreator<MultiSpeciesPlugin, MultiExtension> speciesPluginCreator(speciesExtPoint, packageURIs);
-  SBasePluginCreator<MultiReactionPlugin, MultiExtension> reactionPluginCreator(reactionExtPoint, packageURIs);
   SBasePluginCreator<MultiSimpleSpeciesReferencePlugin, MultiExtension> simplespeciesreferencePluginCreator(simplespeciesreferenceExtPoint, packageURIs);
   SBasePluginCreator<MultiSpeciesReferencePlugin, MultiExtension> speciesreferencePluginCreator(speciesreferenceExtPoint, packageURIs);
 
@@ -376,7 +375,6 @@ MultiExtension::init()
   multiExtension.addSBasePluginCreator(&modelPluginCreator);
   multiExtension.addSBasePluginCreator(&compartmentPluginCreator);
   multiExtension.addSBasePluginCreator(&speciesPluginCreator);
-  multiExtension.addSBasePluginCreator(&reactionPluginCreator);
   multiExtension.addSBasePluginCreator(&simplespeciesreferencePluginCreator);
   multiExtension.addSBasePluginCreator(&speciesreferencePluginCreator);
   MultiASTPlugin multi(getXmlnsL3V1V1());
