@@ -9,7 +9,7 @@
  *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -30,6 +30,9 @@
 #include <sbml/packages/multi/extension/MultiSpeciesPlugin.h>
 #include <sbml/packages/multi/validator/MultiSBMLError.h>
 
+#include <sbml/util/ElementFilter.h>
+#include <sbml/Model.h>
+
 
 using namespace std;
 
@@ -146,6 +149,7 @@ MultiSpeciesPlugin::createObject (XMLInputStream& stream)
         mSpeciesFeatures.getSBMLDocument()->enableDefaultNS(mURI, true); 
       } 
     } 
+    delete multins;
   } 
 
   return object; 
@@ -413,16 +417,16 @@ MultiSpeciesPlugin::getOutwardBindingSite(const std::string& sid) const
   return static_cast<const OutwardBindingSite*>(mOutwardBindingSites.get(sid));
 }
 
-#if 0
+
 /*
  * Returns the OutwardBindingSite object based on its identifier.
- * OutwardBindingSite
  */
+OutwardBindingSite*
 MultiSpeciesPlugin::getOutwardBindingSite(const std::string& sid)
 {
-  return static_cast<const OutwardBindingSite*>(mOutwardBindingSites.get(sid));
+  return static_cast<OutwardBindingSite*>(mOutwardBindingSites.get(sid));
 }
-#endif
+
 
 /*
  * Adds a copy of the given OutwardBindingSite to the ListOfOutwardBindingSites in this plugin object.
@@ -472,6 +476,7 @@ MultiSpeciesPlugin::createOutwardBindingSite ()
   {
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     obs = new OutwardBindingSite(multins);
+    delete multins;
   }
   catch(...)
   {
@@ -565,16 +570,16 @@ MultiSpeciesPlugin::getSpeciesFeature(const std::string& sid) const
   return static_cast<const SpeciesFeature*>(mSpeciesFeatures.get(sid));
 }
 
-#if 0
+
 /*
  * Returns the SpeciesFeature object based on its identifier.
- * SpeciesFeature
  */
+SpeciesFeature*
 MultiSpeciesPlugin::getSpeciesFeature(const std::string& sid)
 {
-  return static_cast<const SpeciesFeature*>(mSpeciesFeatures.get(sid));
+  return static_cast<SpeciesFeature*>(mSpeciesFeatures.get(sid));
 }
-#endif
+
 
 /*
  * Adds a copy of the given SpeciesFeature to the ListOfSpeciesFeatures in this plugin object.
@@ -624,6 +629,7 @@ MultiSpeciesPlugin::createSpeciesFeature ()
   {
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     sf = new SpeciesFeature(multins);
+    delete multins;
   }
   catch(...)
   {
@@ -650,6 +656,7 @@ MultiSpeciesPlugin::createSubListOfSpeciesFeatures ()
   {
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     losf = new ListOfSpeciesFeatures(multins);
+    delete multins;
   }
   catch(...)
   {
