@@ -9,7 +9,7 @@
  *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -125,7 +125,7 @@ OutwardBindingSite::~OutwardBindingSite ()
 /*
  * Returns the value of the "bindingStatus" attribute of this OutwardBindingSite.
  */
-const BindingStatus_t
+BindingStatus_t
 OutwardBindingSite::getBindingStatus() const
 {
   return mBindingStatus;
@@ -453,9 +453,9 @@ OutwardBindingSite::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mComponent, getLevel(), getVersion(), "<OutwardBindingSite>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mComponent) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mComponent) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
         "The syntax of the attribute component='" + mComponent + "' does not conform.");
     }
   }
@@ -678,6 +678,7 @@ ListOfOutwardBindingSites::createObject(XMLInputStream& stream)
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     object = new OutwardBindingSite(multins);
     appendAndOwn(object);
+    delete multins;
   }
 
   return object;
@@ -701,7 +702,8 @@ ListOfOutwardBindingSites::writeXMLNS(XMLOutputStream& stream) const
 
   if (prefix.empty())
   {
-    if (getNamespaces()->hasURI(MultiExtension::getXmlnsL3V1V1()))
+    XMLNamespaces* thisxmlns = getNamespaces();
+    if (thisxmlns && thisxmlns->hasURI(MultiExtension::getXmlnsL3V1V1()))
     {
       xmlns.add(MultiExtension::getXmlnsL3V1V1(),prefix);
     }
