@@ -9,7 +9,7 @@
  *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -30,6 +30,7 @@
 #include <sbml/packages/multi/sbml/SpeciesTypeComponentIndex.h>
 #include <sbml/packages/multi/validator/MultiSBMLError.h>
 
+#include <sbml/util/ElementFilter.h>
 
 using namespace std;
 
@@ -173,7 +174,7 @@ SpeciesTypeComponentIndex::getComponent() const
 /*
  * Returns the value of the "occur" attribute of this SpeciesTypeComponentIndex.
  */
-const unsigned int
+unsigned int
 SpeciesTypeComponentIndex::getOccur() const
 {
   return mOccur;
@@ -510,6 +511,7 @@ SpeciesTypeComponentIndex::createDenotedSpeciesTypeComponentIndex()
   {
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     dstci = new DenotedSpeciesTypeComponentIndex(multins);
+    delete multins;
   }
   catch (...)
   {
@@ -724,6 +726,7 @@ SpeciesTypeComponentIndex::createObject(XMLInputStream& stream)
     object = &mDenotedSpeciesTypeComponentIndexes;
   }
 
+  delete multins;
   return object;
 }
 
@@ -837,9 +840,10 @@ SpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mId, getLevel(), getVersion(), "<SpeciesTypeComponentIndex>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mId) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mId) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax);
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
+        "The syntax of the attribute id='" + mId + "' does not conform.");
     }
   }
   else
@@ -862,9 +866,9 @@ SpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mComponent, getLevel(), getVersion(), "<SpeciesTypeComponentIndex>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mComponent) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mComponent) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
         "The syntax of the attribute component='" + mComponent + "' does not conform.");
     }
   }
@@ -914,9 +918,9 @@ SpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mIdentifyingParent, getLevel(), getVersion(), "<SpeciesTypeComponentIndex>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mIdentifyingParent) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mIdentifyingParent) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
         "The syntax of the attribute identifyingParent='" + mIdentifyingParent 
         + "' does not conform.");
     }
@@ -1112,6 +1116,7 @@ ListOfSpeciesTypeComponentIndexes::createObject(XMLInputStream& stream)
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     object = new SpeciesTypeComponentIndex(multins);
     appendAndOwn(object);
+    delete multins;
   }
 
   return object;
@@ -1135,7 +1140,8 @@ ListOfSpeciesTypeComponentIndexes::writeXMLNS(XMLOutputStream& stream) const
 
   if (prefix.empty())
   {
-    if (getNamespaces()->hasURI(MultiExtension::getXmlnsL3V1V1()))
+    XMLNamespaces* thisxmlns = getNamespaces();
+    if (thisxmlns && thisxmlns->hasURI(MultiExtension::getXmlnsL3V1V1()))
     {
       xmlns.add(MultiExtension::getXmlnsL3V1V1(),prefix);
     }
