@@ -9,7 +9,7 @@
  *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -181,7 +181,7 @@ SpeciesTypeInstance::getCompartmentReference() const
 /*
  * Returns the value of the "occur" attribute of this SpeciesTypeInstance.
  */
-const unsigned int
+unsigned int
 SpeciesTypeInstance::getOccur() const
 {
   return mOccur;
@@ -649,9 +649,10 @@ SpeciesTypeInstance::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mId, getLevel(), getVersion(), "<SpeciesTypeInstance>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mId) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mId) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax);
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
+        "The syntax of the attribute id='" + mId + "' does not conform.");
     }
   }
   else
@@ -689,9 +690,9 @@ SpeciesTypeInstance::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mSpeciesType, getLevel(), getVersion(), "<SpeciesTypeInstance>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mSpeciesType) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mSpeciesType) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
         "The syntax of the attribute speciesType='" + mSpeciesType + "' does not conform.");
     }
   }
@@ -715,9 +716,9 @@ SpeciesTypeInstance::readAttributes (const XMLAttributes& attributes,
     {
       logEmptyString(mCompartmentReference, getLevel(), getVersion(), "<SpeciesTypeInstance>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mCompartmentReference) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mCompartmentReference) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
         "The syntax of the attribute compartmentReference='" + 
         mCompartmentReference + "' does not conform.");
     }
@@ -942,6 +943,7 @@ ListOfSpeciesTypeInstances::createObject(XMLInputStream& stream)
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     object = new SpeciesTypeInstance(multins);
     appendAndOwn(object);
+    delete multins;
   }
 
   return object;
@@ -965,7 +967,8 @@ ListOfSpeciesTypeInstances::writeXMLNS(XMLOutputStream& stream) const
 
   if (prefix.empty())
   {
-    if (getNamespaces()->hasURI(MultiExtension::getXmlnsL3V1V1()))
+    XMLNamespaces* thisxmlns = getNamespaces();
+    if (thisxmlns && thisxmlns->hasURI(MultiExtension::getXmlnsL3V1V1()))
     {
       xmlns.add(MultiExtension::getXmlnsL3V1V1(),prefix);
     }
