@@ -89,6 +89,12 @@ public:
    */
   LocalRenderInformation (RenderPkgNamespaces* renderns);
 
+  /**
+   * Destroy this LocalRenderInformation object.
+   */
+  virtual ~LocalRenderInformation ();
+
+
   /**
    * Parses the xml information in the given node and sets the attributes.
    * This method should never be called by the user. It is only used to read render 
