@@ -33,6 +33,8 @@
 
 #include "RenderGroup.h"
 
+#include <sbml/util/ElementFilter.h>
+
 #include <algorithm>
 #include <functional>
 #include <limits>
@@ -808,6 +810,7 @@ Image* RenderGroup::createImage()
     {
       RENDER_CREATE_NS(renderns, this->getSBMLNamespaces());
       pImage = new Image(renderns);
+	 delete renderns;
     }
     catch (...)
     {
@@ -841,6 +844,7 @@ RenderGroup* RenderGroup::createGroup()
     {
       RENDER_CREATE_NS(renderns, this->getSBMLNamespaces());
       pRenderGroup = new RenderGroup(renderns);
+	 delete renderns;
     }
     catch (...)
     {
@@ -874,6 +878,7 @@ Rectangle* RenderGroup::createRectangle()
     {
       RENDER_CREATE_NS(renderns, this->getSBMLNamespaces());
       pRectangle = new Rectangle(renderns);
+	 delete renderns;
     }
     catch (...)
     {
@@ -907,6 +912,7 @@ Ellipse* RenderGroup::createEllipse()
     {
       RENDER_CREATE_NS(renderns, this->getSBMLNamespaces());
       pEllipse = new Ellipse(renderns);
+	 delete renderns;
     }
     catch (...)
     {
@@ -940,6 +946,7 @@ RenderCurve* RenderGroup::createCurve()
     {
       RENDER_CREATE_NS(renderns, this->getSBMLNamespaces());
       pRenderCurve = new RenderCurve(renderns);
+	 delete renderns;
     }
     catch (...)
     {
@@ -973,6 +980,7 @@ Polygon* RenderGroup::createPolygon()
     {
       RENDER_CREATE_NS(renderns, this->getSBMLNamespaces());
       pPolygon = new Polygon(renderns);
+	 delete renderns;
     }
     catch (...)
     {
@@ -1006,6 +1014,7 @@ Text* RenderGroup::createText()
     {
       RENDER_CREATE_NS(renderns, this->getSBMLNamespaces());
       pText = new Text(renderns);
+	 delete renderns;
     }
     catch (...)
     {
@@ -1392,8 +1401,8 @@ void RenderGroup::importOldCurve(const XMLNode& node)
     const XMLAttributes& curveAttributes=node.getAttributes();
     const XMLNode* child;
     unsigned int n=0,nMax = node.getNumChildren();
-    const XMLNode* pOrigAnnotation=NULL;
-    const XMLNode* pOrigNotes=NULL;
+    //const XMLNode* pOrigAnnotation=NULL;
+    //const XMLNode* pOrigNotes=NULL;
     RENDER_CREATE_NS(renderns, this->getSBMLNamespaces());
     while(n<nMax)
     {
@@ -1546,16 +1555,17 @@ void RenderGroup::importOldCurve(const XMLNode& node)
                 this->mElements.appendAndOwn(pCurve);
             }
         }
-        else if(childName=="annotation")
-        {
-            pOrigAnnotation=child;
-        }
-        else if(childName=="notes")
-        {
-            pOrigNotes=child;
-        }
+        //else if(childName=="annotation")
+        //{
+        //    pOrigAnnotation=child;
+        //}
+        //else if(childName=="notes")
+        //{
+        //    pOrigNotes=child;
+        //}
         ++n;
     }
+    delete renderns;
 }
 /** @endcond */
 
@@ -1866,6 +1876,7 @@ SBase* ListOfDrawables::createObject (XMLInputStream& stream)
        object = new Image(renderns);
     } 
     if(object) this->mItems.push_back(object);
+    delete renderns;
     return object;
 }
 /** @endcond */
