@@ -321,28 +321,27 @@ typedef enum
   , SBML_SPATIAL_ANALYTICVOLUME    = 312
   , SBML_SPATIAL_PARAMETRICGEOMETRY = 313
   , SBML_SPATIAL_PARAMETRICOBJECT  = 314
-  , SBML_SPATIAL_POLYGONOBJECT     = 315
-  , SBML_SPATIAL_SPATIALPOINT      = 316
-  , SBML_SPATIAL_CSGEOMETRY        = 317
-  , SBML_SPATIAL_CSGOBJECT         = 318
-  , SBML_SPATIAL_CSGNODE           = 319
-  , SBML_SPATIAL_CSGTRANSFORMATION = 320
-  , SBML_SPATIAL_CSGTRANSLATION    = 321
-  , SBML_SPATIAL_CSGROTATION       = 322
-  , SBML_SPATIAL_CSGSCALE          = 323
-  , SBML_SPATIAL_CSGHOMOGENEOUSTRANSFORMATION = 324
-  , SBML_SPATIAL_TRANSFORMATIONCOMPONENTS = 325
-  , SBML_SPATIAL_CSGPRIMITIVE      = 326
-  , SBML_SPATIAL_CSGPSEUDOPRIMITIVE = 327
-  , SBML_SPATIAL_CSGSETOPERATOR    = 328
-  , SBML_SPATIAL_SPATIALSYMBOLREFERENCE = 329
-  , SBML_SPATIAL_DIFFUSIONCOEFFICIENT = 330
-  , SBML_SPATIAL_ADVECTIONCOEFFICIENT = 331
-  , SBML_SPATIAL_BOUNDARYCONDITION = 332
-  , SBML_SPATIAL_GEOMETRY          = 333
-  , SBML_SPATIAL_COORDINATEREFERENCE = 334
-  , SBML_SPATIAL_MIXEDGEOMETRY     = 335
-  , SBML_SPATIAL_ORDINALMAPPING    = 336
+  , SBML_SPATIAL_CSGEOMETRY        = 315
+  , SBML_SPATIAL_CSGOBJECT         = 316
+  , SBML_SPATIAL_CSGNODE           = 317
+  , SBML_SPATIAL_CSGTRANSFORMATION = 318
+  , SBML_SPATIAL_CSGTRANSLATION    = 319
+  , SBML_SPATIAL_CSGROTATION       = 320
+  , SBML_SPATIAL_CSGSCALE          = 321
+  , SBML_SPATIAL_CSGHOMOGENEOUSTRANSFORMATION = 322
+  , SBML_SPATIAL_TRANSFORMATIONCOMPONENTS = 323
+  , SBML_SPATIAL_CSGPRIMITIVE      = 324
+  , SBML_SPATIAL_CSGPSEUDOPRIMITIVE = 325
+  , SBML_SPATIAL_CSGSETOPERATOR    = 326
+  , SBML_SPATIAL_SPATIALSYMBOLREFERENCE = 327
+  , SBML_SPATIAL_DIFFUSIONCOEFFICIENT = 328
+  , SBML_SPATIAL_ADVECTIONCOEFFICIENT = 329
+  , SBML_SPATIAL_BOUNDARYCONDITION = 330
+  , SBML_SPATIAL_GEOMETRY          = 331
+  , SBML_SPATIAL_COORDINATEREFERENCE = 332
+  , SBML_SPATIAL_MIXEDGEOMETRY     = 333
+  , SBML_SPATIAL_ORDINALMAPPING    = 334
+  , SBML_SPATIAL_SPATIALPOINTS     = 335
 } SBMLSpatialTypeCode_t;
 
 
