@@ -54,9 +54,9 @@ SpatialParameterPlugin::SpatialParameterPlugin(const std::string& uri,
                                  const std::string& prefix, 
                                SpatialPkgNamespaces* spatialns) :
     SBasePlugin(uri, prefix, spatialns)
-  , mSpatialSymbolReference( NULL )
+  , mSpatialSymbolReference  ( NULL )
   , mAdvectionCoefficient  ( NULL )
-  , mBoundaryCondition     ( NULL )
+  , mBoundaryCondition  ( NULL )
   , mDiffusionCoefficient  ( NULL )
 {
 }
@@ -67,21 +67,25 @@ SpatialParameterPlugin::SpatialParameterPlugin(const std::string& uri,
  */
 SpatialParameterPlugin::SpatialParameterPlugin(const SpatialParameterPlugin& orig) :
     SBasePlugin(orig)
-  , mSpatialSymbolReference( NULL )
-  , mAdvectionCoefficient  ( NULL )
-  , mBoundaryCondition     ( NULL )
-  , mDiffusionCoefficient  ( NULL )
+  , mSpatialSymbolReference ( NULL )
+  , mAdvectionCoefficient ( NULL )
+  , mBoundaryCondition ( NULL )
+  , mDiffusionCoefficient ( NULL )
 {
-  if (orig.mSpatialSymbolReference != NULL) {
+  if (orig.mSpatialSymbolReference != NULL)
+  {
     mSpatialSymbolReference = orig.mSpatialSymbolReference->clone();
   }
-  if (orig.mAdvectionCoefficient != NULL) {
+  if (orig.mAdvectionCoefficient != NULL)
+  {
     mAdvectionCoefficient = orig.mAdvectionCoefficient->clone();
   }
-  if (orig.mBoundaryCondition != NULL) {
+  if (orig.mBoundaryCondition != NULL)
+  {
     mBoundaryCondition = orig.mBoundaryCondition->clone();
   }
-  if (orig.mDiffusionCoefficient != NULL) {
+  if (orig.mDiffusionCoefficient != NULL)
+  {
     mDiffusionCoefficient = orig.mDiffusionCoefficient->clone();
   }
 }
@@ -96,19 +100,22 @@ SpatialParameterPlugin::operator=(const SpatialParameterPlugin& rhs)
   if (&rhs != this)
   {
     this->SBasePlugin::operator=(rhs);
-    deleteChildren();
-    if (rhs.mSpatialSymbolReference != NULL) {
+    delete mSpatialSymbolReference;
+    mSpatialSymbolReference = NULL;
+    if (rhs.mSpatialSymbolReference != NULL)
       mSpatialSymbolReference = rhs.mSpatialSymbolReference->clone();
-    }
-    if (rhs.mAdvectionCoefficient != NULL) {
+    delete mAdvectionCoefficient;
+    mAdvectionCoefficient = NULL;
+    if (rhs.mAdvectionCoefficient != NULL)
       mAdvectionCoefficient = rhs.mAdvectionCoefficient->clone();
-    }
-    if (rhs.mBoundaryCondition != NULL) {
+    delete mBoundaryCondition;
+    mBoundaryCondition = NULL;
+    if (rhs.mBoundaryCondition != NULL)
       mBoundaryCondition = rhs.mBoundaryCondition->clone();
-    }
-    if (rhs.mDiffusionCoefficient != NULL) {
+    delete mDiffusionCoefficient;
+    mDiffusionCoefficient = NULL;
+    if (rhs.mDiffusionCoefficient != NULL)
       mDiffusionCoefficient = rhs.mDiffusionCoefficient->clone();
-    }
   }
 
   return *this;
@@ -129,21 +136,18 @@ SpatialParameterPlugin::clone () const
  * Destructor for SpatialParameterPlugin.
  */
 SpatialParameterPlugin::~SpatialParameterPlugin()
-{
-  deleteChildren();
-}
-
-void SpatialParameterPlugin::deleteChildren()
 {
   delete mSpatialSymbolReference;
-  delete mAdvectionCoefficient;
-  delete mBoundaryCondition;
-  delete mDiffusionCoefficient;
   mSpatialSymbolReference = NULL;
+  delete mAdvectionCoefficient;
   mAdvectionCoefficient = NULL;
+  delete mBoundaryCondition;
   mBoundaryCondition = NULL;
+  delete mDiffusionCoefficient;
   mDiffusionCoefficient = NULL;
 }
+
+
 //---------------------------------------------------------------
 //
 // overridden virtual functions for read/write/check
@@ -299,8 +303,6 @@ SpatialParameterPlugin::readAttributes (const XMLAttributes& attributes,
     }
   }
 
-  //bool assigned = false;
-
 }
 
 
