@@ -450,18 +450,21 @@ AdvectionCoefficient::readAttributes (const XMLAttributes& attributes,
   // coordinate enum  ( use = "required" )
   //
   mCoordinate = COORDINATEKIND_UNKNOWN;
-  std::string stringValue;
-  assigned = attributes.readInto("coordinate", stringValue);
-
-  if (assigned == true)
   {
-    // parse enum
+    std::string stringValue;
+    assigned = attributes.readInto("coordinate", stringValue);
 
-    mCoordinate = CoordinateKind_parse(stringValue.c_str());
-    if(mCoordinate == COORDINATEKIND_UNKNOWN) {
-      std::string message = "Unknown value for spatial attribute 'coordinate' in 'advectionCoefficient' object: " + stringValue;
-      getErrorLog()->logPackageError("spatial", SpatialUnknownError,
-        getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
+    if (assigned == true)
+    {
+      // parse enum
+
+      mCoordinate = CoordinateKind_parse(stringValue.c_str());
+      if(mCoordinate == COORDINATEKIND_UNKNOWN)
+      {
+        std::string message = "Unknown value for Spatial attribute 'coordinate' in 'advectionCoefficient' object: " + stringValue;
+        getErrorLog()->logPackageError("spatial", SpatialUnknownError,
+                       getPackageVersion(), sbmlLevel, sbmlVersion, message, getLine(), getColumn());
+      }
     }
   }
   if(mCoordinate == COORDINATEKIND_UNKNOWN)
