@@ -314,6 +314,7 @@ CSGeometry::getAllElements(ElementFilter* filter)
   List* ret = new List();
   List* sublist = NULL;
 
+  ADD_FILTERED_LIST(ret, sublist, mCsgObjects, filter);
 
   ADD_FILTERED_FROM_PLUGIN(ret, sublist, filter);
 
@@ -474,6 +475,7 @@ CSGeometry::createObject(XMLInputStream& stream)
   {
     object = &mCsgObjects;
   }
+
   connectToChild();
 
 
@@ -541,8 +543,6 @@ CSGeometry::readAttributes (const XMLAttributes& attributes,
     }
   }
 
-  //bool assigned = false;
-
 }
 
 
