@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -63,25 +68,38 @@ using namespace std;
 LIBSBML_CPP_NAMESPACE_BEGIN
 
 
-SBMLInternalValidator::SBMLInternalValidator() : SBMLValidator()
+SBMLInternalValidator::SBMLInternalValidator() 
+  : SBMLValidator()
+  , mApplicableValidators(0)
+  , mApplicableValidatorsForConversion(0)
 {
 
 }
 
 
-SBMLInternalValidator::SBMLInternalValidator(const SBMLInternalValidator& orig) :
-SBMLValidator(orig), mApplicableValidators(orig.mApplicableValidators), 
-  mApplicableValidatorsForConversion(orig.mApplicableValidatorsForConversion)
+SBMLInternalValidator::SBMLInternalValidator(const SBMLInternalValidator& orig) 
+  : SBMLValidator(orig)
+  , mApplicableValidators(orig.mApplicableValidators)
+  , mApplicableValidatorsForConversion(orig.mApplicableValidatorsForConversion)
 {
 }
 
 SBMLValidator* 
-  SBMLInternalValidator::clone() const
+SBMLInternalValidator::clone() const
 {
   return new SBMLInternalValidator(*this);
 }
 
 
+/*
+ * Destroy this object.
+ */
+SBMLInternalValidator::~SBMLInternalValidator ()
+{
+
+}
+
+
 void 
 SBMLInternalValidator::setConsistencyChecks(SBMLErrorCategory_t category,
                                    bool apply)
@@ -309,14 +327,6 @@ SBMLInternalValidator::checkConsistency (bool writeDocument)
   }
   */
 
-  IdentifierConsistencyValidator id_validator;
-  ConsistencyValidator validator;
-  SBOConsistencyValidator sbo_validator;
-  MathMLConsistencyValidator math_validator;
-  UnitConsistencyValidator unit_validator;
-  OverdeterminedValidator over_validator;
-  ModelingPracticeValidator practice_validator;
-
   SBMLDocument *doc;
   SBMLErrorLog *log = getErrorLog();
   
@@ -335,8 +345,26 @@ SBMLInternalValidator::checkConsistency (bool writeDocument)
   /* calls each specified validator in turn 
    * - stopping when errors are encountered */
 
+  /* look to see if we have serious errors from the read
+   * these may cause other validators to crash
+   * although hopefully not it is probably best to guard
+   * against trying
+   */
+  bool seriousErrors = doc->getNumErrors(LIBSBML_SEV_FATAL) > 0
+    || doc->getNumErrors(LIBSBML_SEV_ERROR) > 0;
+
+
+  // do not try and go further but do not report the errors as these
+  // will have been recorded elsewhere and do not come from the validators
+  if (seriousErrors == true)
+  {
+    return 0;
+  }
+
+
   if (id)
   {
+    IdentifierConsistencyValidator id_validator;
     id_validator.init();
     nerrors = id_validator.validate(*doc);
     if (nerrors > 0) 
@@ -393,6 +421,7 @@ SBMLInternalValidator::checkConsistency (bool writeDocument)
 
   if (sbml)
   {
+    ConsistencyValidator validator;
     validator.init();
     nerrors = validator.validate(*doc);
     total_errors += nerrors;
@@ -411,6 +440,7 @@ SBMLInternalValidator::checkConsistency (bool writeDocument)
 
   if (sbo)
   {
+    SBOConsistencyValidator sbo_validator;
     sbo_validator.init();
     nerrors = sbo_validator.validate(*doc);
     total_errors += nerrors;
@@ -429,6 +459,7 @@ SBMLInternalValidator::checkConsistency (bool writeDocument)
 
   if (math)
   {
+    MathMLConsistencyValidator math_validator;
     math_validator.init();
     nerrors = math_validator.validate(*doc);
     total_errors += nerrors;
@@ -447,6 +478,7 @@ SBMLInternalValidator::checkConsistency (bool writeDocument)
 
   if (units)
   {
+    UnitConsistencyValidator unit_validator;
     unit_validator.init();
     nerrors = unit_validator.validate(*doc);
     total_errors += nerrors;
@@ -467,6 +499,7 @@ SBMLInternalValidator::checkConsistency (bool writeDocument)
    * changed this as would have bailed */
   if (over)
   {
+    OverdeterminedValidator over_validator;
     over_validator.init();
     nerrors = over_validator.validate(*doc);
     total_errors += nerrors;
@@ -485,6 +518,7 @@ SBMLInternalValidator::checkConsistency (bool writeDocument)
 
   if (practice)
   {
+    ModelingPracticeValidator practice_validator;
     practice_validator.init();
     nerrors = practice_validator.validate(*doc);
     if (nerrors > 0) 
@@ -726,7 +760,7 @@ unsigned int
   return checkConsistency();  
 }
 
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 
 /** @endcond */
