@@ -9,9 +9,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2014 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -212,17 +217,32 @@ START_CONSTRAINT (20509, Compartment, c)
   const UnitDefinition* defn  = m.getUnitDefinition(units);
 
   /* dimensionless is allowable in L2V2 */
-  if ( c.getLevel() == 1
-    || (c.getLevel() == 2 && c.getVersion() == 1))
+  if ( c.getLevel() == 1)
   {
     inv_or( units == "volume" );
     inv_or( units == "litre"  );
-    inv_or( units == "liter" && c.getLevel() == 1 );
+    inv_or( units == "liter"  );
     inv_or( defn  != NULL && defn->isVariantOfVolume() );
   }
+  else if (c.getLevel() == 2)
+  {
+    if (c.getVersion() == 1)
+    {
+    inv_or( units == "volume" );
+    inv_or( units == "litre"  );
+    inv_or( defn  != NULL && defn->isVariantOfVolume() );
+    }
+    else
+    {
+      inv_or( units == "volume" );
+      inv_or( units == "litre"  );
+      inv_or( units == "dimensionless"  );
+      inv_or( defn  != NULL && defn->isVariantOfVolume() );
+      inv_or( defn  != NULL && defn->isVariantOfDimensionless() );
+    }
+  }
   else
   {
-    inv_or( units == "volume" );
     inv_or( units == "litre"  );
     inv_or( units == "dimensionless"  );
     inv_or( defn  != NULL && defn->isVariantOfVolume() );
@@ -304,7 +324,6 @@ START_CONSTRAINT (20608, Species, s)
   }
   else if (s.getLevel() == 3)
   {
-    inv_or( units == "substance"      );
     inv_or( units == "item"           );
     inv_or( units == "mole"           );
     inv_or( units == "dimensionless"  );
@@ -529,42 +548,52 @@ END_CONSTRAINT
 START_CONSTRAINT (99508, Compartment, c)
 {
   pre ( c.getLevel() > 2);
-  pre ( c.getDerivedUnitDefinition() != NULL);
+  const UnitDefinition * ud = c.getDerivedUnitDefinition();
+  pre ( ud != NULL);
   
   msg = "The units of the <compartment> '";
   msg += c.getId() ;
   msg += "' cannot be fully checked. Unit consistency reported as either no errors ";
   msg += "or further unit errors related to this object may not be accurate.";
 
-  inv( !(c.getDerivedUnitDefinition()->getNumUnits() == 0));
+  inv( !(ud->getNumUnits() == 0));
 }
 END_CONSTRAINT
 
 START_CONSTRAINT (99508, Species, s)
 {
   pre ( s.getLevel() > 2);
-  pre ( s.getDerivedUnitDefinition() != NULL);
+  const UnitDefinition * ud = s.getDerivedUnitDefinition();
+  pre ( ud != NULL);
   
   msg = "The units of the <species> '";
   msg += s.getId() ;
   msg += "' cannot be fully checked. Unit consistency reported as either no errors ";
   msg += "or further unit errors related to this object may not be accurate.";
 
-  inv( !(s.getDerivedUnitDefinition()->getNumUnits() == 0));
+  inv( !(ud->getNumUnits() == 0));
 }
 END_CONSTRAINT
 
 START_CONSTRAINT (99508, Parameter, p)
 {
   pre ( p.getLevel() > 2);
-  pre ( p.getDerivedUnitDefinition() != NULL);
+  UnitDefinition * ud =  const_cast<UnitDefinition*>(p.getDerivedUnitDefinition());
+  
+  bool isNotNull = ud != NULL;
+  int numUnits = isNotNull ? ud->getNumUnits() : 0;
+  
+  if (!isNotNull)  
+
+  pre ( isNotNull);
   
   msg = "The units of the <parameter> '";
   msg += p.getId() ;
   msg += "' cannot be fully checked. Unit consistency reported as either no errors ";
   msg += "or further unit errors related to this object may not be accurate.";
 
-  inv( !(p.getDerivedUnitDefinition()->getNumUnits() == 0));
+  inv( !(numUnits == 0));  
+
 }
 END_CONSTRAINT
 
@@ -1392,7 +1421,7 @@ START_CONSTRAINT (10541, KineticLaw, kl)
   msg += ".";
 
 
-  inv (UnitDefinition::areEquivalent(formulaUnits->getUnitDefinition(), 
+  inv (UnitDefinition::areIdentical(formulaUnits->getUnitDefinition(), 
                                       variableUnits->getUnitDefinition()) == 1);
 }
 END_CONSTRAINT
